libname lbd '/economic/lbd/microdata';
libname cfs '/economic/cfs/microdata';
libname cmf '/economic/cmf.old/microdata';
libname cfs '/economic/cfs/microdata';
libname ocd '/economic/ocd/microdata';
libname outside '/rdcprojects/ch/ch00573/data/outside';
libname dat '/rdcprojects/ch/ch00573/data';

/* This file contains the calculations that will be used in the (STATA) analysis corresponding to Tables 6, A7-A10
of the paper.  */

/* This sas file contains three parts.  

In the first part, we identify establishments that have changed ownership between 1987 and 1997.  

In the second part of the code, we merge the data on sold establishments with production data.  
The output of this part of code will help answer the question Do purchased establishments begin producing 
the same products that the buynig firm has been producing?

In the third part of the code, we merge the data on sold establishments with shipment data.  
The output of this part of code will help answer the question, Do purchased establishments begin 
shipping to the same zip codes that the buying firm had been shipping to? */

/* This first short piece of code retrieves the zip codes of each establishment.  
This will be useful in the shipment regressions, as one of the independent variables is an
 indicator, equal to 1 when there is an establishment of the merged firm, in 1997, in the destination zip code */

data lbd97 (keep=emp zip5 firmid);
  set lbd.lbd1997c;
  if emp=. OR firmid="" OR firmid="      0000" then delete;
  zip5=substr(zip,1,5);
run;
proc sort data=lbd97;
   by firmid  zip5;
run;
proc summary data=lbd97;
  var emp;
  output out =firmlo (drop=_type_ _freq_) n=plants sum=sumemp;
  by firmid zip5;
run;
data firmlo; 
  set firmlo;
  rename sumemp=emp;
run;
proc export data=firmlo    outfile = "firmlocs.csv"     replace    dbms = CSV;    delimiter = ',';  run;

/* Get establishments who are acquired, according to the Ownership Change Database */

%macro ocd(yr);

%let yr1 =%eval(&yr +1); 
%let yr2 =%eval(&yr +2); 
%let yr3 =%eval(&yr +3); 
%let yr4 =%eval(&yr +4); 
%let yr5 =%eval(&yr +5); 
%let yr6 =%eval(&yr +1900);

data ocd&yr (keep= buyid sellid ppn ppn2 status ); 
  set ocd.ocd&yr6.&yr5  ;
  if status="ACQUIRED";
  ppn2=ppn/1;
  if buyid<1e7 then buyid=buyid*1e4;
  if sellid<1e7 then sellid=sellid*1e4;
  if id97<1e7 then id97=id97*1e4;
run;

proc append base=ocd data=ocd&yr force;

%mend;

%ocd(87);    

data ocd92 (keep= buyid sellid ppn ppn2 status); 
  set ocd.ocd199297 ;
  if buyid<1e7 then buyid=buyid*1e4;
  if sellid<1e7 then sellid=sellid*1e4;
  if id97<1e7 then id97=id97*1e4;
  ppn2=ppn/1;
  if status="acqu93" OR  status="acqu92" OR status="acqu94" OR status="acqu95" OR status="acqu96" OR status="acqu97";
run;

proc append base=ocd data=ocd92 force;
data ocd (drop=ppn);
  set ocd; 
  if ppn2= . then delete;
run;

data ocd (drop=status buyid sellid);
  set ocd;
  ppn=int(ppn2);
  buyer=put(buyid,10.);
  ownf=put(sellid,10.);
  if buyid<1e6  then buyer="0000" || left(buyer);
  if sellid<1e6 then ownf="0000" || left(ownf);
  if buyid<1e7 AND buyid>1e6 then buyer="000" || left(buyer);
  if sellid<1e7 AND sellid>1e6 then ownf="000" || left(ownf);
  if buyid<1e8  AND buyid>1e7 then buyer="00" || left(buyer);
  if sellid<1e8 AND sellid>1e7 then ownf="00" || left(ownf);
  if buyid<1e9 AND buyid>1e8 then buyer="0" || left(buyer);
  if sellid<1e9 AND sellid>1e8 then ownf="0" || left(ownf);
run;

proc sort data=ocd nodupkey;
   by ppn ownf buyer;
run;
/* Get lbdnumbers from the cmf dataset */
%macro ocdLBD(yr); 

data cm1 (keep=ppn2  lbdnum);
  set cmf.cmf19&yr;
  ppn2=int(ppn/1);
run;

proc sql noprint;
  create table ocdT as 
  select a.*, b.lbdnum
  from ocd as a left join cm1 as b
  on a.ppn=b.ppn2;

data ocdT2;
  set ocdT;
  if lbdnum~="";
run;
data ocd (drop=lbdnum);
  set ocdT;
  if lbdnum="";
run;
proc append base=ocdInter data=ocdT2;
proc sort data=ocdInter nodupkey;
  by ppn buyer ownf;
run;

%mend;

%ocdLBD(87); %ocdLBD(92); %ocdLBD(97);  

/* Next get the years in which the mergers occurred, by looking at the date at which the firm identifier changed. 
 The OCD lists the change of ownership year, but only for 1992-1997.  */

%macro ocdYr(yr);
proc sql noprint;
   create table ocdTemp as 
   select a.*, b.yr
   from ocdInter as a left join lbd.lbd19&yr.c as b
   on a.lbdnum=b.lbdnum AND a.buyer=b.firmid;
data ocdInter  (drop=yr);
   set ocdTemp;
   if yr=.;
run;
data ocdTemp2 (drop=yr);
   set ocdTemp;
   if yr~=.;
   mrgeyr=yr-1;
run;
proc append base=ocdFinal data=ocdTemp2;
%mend;

%ocdYr(87); %ocdYr(88); %ocdYr(89); %ocdYr(90); %ocdYr(91); %ocdYr(92); %ocdYr(93); %ocdYr(94); %ocdYr(95);
%ocdYr(96); %ocdYr(97); %ocdYr(98);

proc export data=ocdFinal outfile = "ocdFinal.csv"     replace    dbms = CSV;    delimiter = ','; run; 

/* This part of code also generates a list of acquired establishments; this part, though, does not use the Ownership Change Database.  
Instead, we look at the establsihments which change  firm identifiers in the LBD.  */

data lbd86 (keep=emp firmid);
  set lbd.lbd1986c;
  if cfn~="" AND emp~=. AND firmid~="";
run;

proc sort data=lbd86;
  by firmid;
run;

proc summary data=lbd86;
  var emp;
  output out=l86 (drop=_type_ _freq_) sum=empF86 n=plantsF86;
  by firmid;
run;
/* Get the plants that change firm ids from one year to the next */  
                     /* Also get the number of plants (and employment) in the firm at year t and t+1 */
%macro oneyear1(y);  
%let q=%eval(&y+1);
%let c=c;
%let in=in;
%let yc=&y&c;
%let qc=&q&c;
%let yinq=&y&in&q;
%let qiny=&q&in&y;

data lbd&q (keep=emp firmid);
  set lbd.lbd19&qc;
  if cfn~="" AND emp~=. AND firmid~="" AND firmid~="      0000";
run;
proc sort data=lbd&q;
  by firmid;
run;
proc summary data=lbd&q;
  var emp;
  output out=l&q (drop=_type_ _freq_) sum=empF&q n=plantsF&q;
  by firmid;
run;
proc sql noprint;
  create table change&y as 
  select a.lbdnum as lbdnum&y
  from lbd.lbd19&yc as a, lbd.lbd19&qc as b  
  where a.lbdnum=b.lbdnum AND a.firmid~=b.firmid AND a.emp~=. AND b.emp~=. AND b.firmid~="" AND b.cfn~="" AND a.cfn~="";

%mend;

%oneyear1(86); %oneyear1(87); %oneyear1(88); %oneyear1(89);
%oneyear1(90); %oneyear1(91); %oneyear1(92); %oneyear1(93); %oneyear1(94); %oneyear1(95); %oneyear1(96); 

/* Combine all of the change&y datasets into one big dataset.  Begin by combining change86 and change87 */
proc sql noprint;  
  create table changeA as 
  select a.lbdnum86, b.lbdnum87 
  from change86 as a full join change87 as b
  on a.lbdnum86=b.lbdnum87;

data change1A (drop=lbdnum86 lbdnum87);
  set changeA;
  lbdnum=lbdnum86;
  if lbdnum87 ~="" then lbdnum=lbdnum87;
run;

proc sort data=change1A nodupkey;
  by lbdnum;
run;

%macro oneyearB(yr);

proc sql noprint;
  create table changeA as 
  select a.lbdnum, b.lbdnum&yr
  from change1A as a full join change&yr as b
  on a.lbdnum=b.lbdnum&yr;

data change1A (drop=lbdnum&yr);
  set changeA;
  if lbdnum&yr ~="" then lbdnum=lbdnum&yr;
run;

proc sort data=change1A nodupkey;
  by lbdnum;
run;

%mend;

%oneyearB(88); %oneyearB(89); %oneyearB(91); %oneyearB(92);
%oneyearB(93); %oneyearB(94); %oneyearB(95); %oneyearB(96);

 /* The LBD contains several variables that identify the industry of the establishment.  Why is bestsic the best one? 
 Unlike some of the other industry variables, bestsic is designed to be comparable across time.  In particular, even 
though SIC/NAICS categorizations change across time, bestsic is stated in terms of the 1987 classification (regardless of the sample year).  */

proc sql noprint; 
  create table changeB as 
  select a.*, b.firmid as firmid86, b.emp as emp86, b.cfn as cfn86, b.mu as mu86, b.bestsic as bestsic86  
  from change1A as a left join lbd.lbd1986c as b
  on a.lbdnum=b.lbdnum;
  create table changeA as 
  select a.*, b.firmid as firmid87, b.emp as emp87, b.cfn as cfn87, b.mu as mu87, b.bestsic as bestsic87
  from changeB as a left join lbd.lbd1987c as b
  on a.lbdnum=b.lbdnum;

proc sql noprint;
  create table changeB as 
  select a.*, b.empF86, b.plantsF86  
  from changeA as a left join l86 as b
  on a.firmid86=b.firmid;
  create table changeA as 
  select a.*, b.empF87, b.plantsF87  
  from changeB as a left join l87 as b
  on a.firmid87=b.firmid;
  create table changeB as 
  select a.*, b.empF87 as empF86in87, b.plantsF87 as plantsF86in87  
  from changeA as a left join l87 as b
  on a.firmid86=b.firmid;
  create table change1A as 
  select a.*, b.empF86 as empF87in86, b.plantsF86 as plantsF87in86
  from changeB as a left join l86 as b
  on a.firmid87=b.firmid;

/* Here 86in87 (or something similar means we count the number of plants (or sum of the employment) in 1987 
of establishments that have a particular firmid in 1986.  The reverse (87in86) counts the number of establishments in 1986 
or plants that have a certain firmid in 1987. */

data change1A;
  set change1A;
  if lbdnum~="";
run;

proc sort data=change1A nodupkey;
  by lbdnum;
run;

%macro oneyear2(y); 

%let q=%eval(&y+1);
%let c=c;
%let in=in;
%let yc=&y&c;
%let qc=&q&c;
%let yinq=&y&in&q;
%let qiny=&q&in&y;

proc sql noprint; 
  create table changeA as 
  select a.*, b.firmid as firmid&q, b.emp as emp&q, b.cfn as cfn&q, b.mu as mu&q, b.bestsic as bestsic&q
  from change1A as a left join lbd.lbd19&qc as b
  on a.lbdnum=b.lbdnum;
  create table changeC as 
  select a.*, b.empF&q, b.plantsF&q  
  from changeA as a left join l&q as b
  on a.firmid&q=b.firmid;
  create table changeB as 
  select a.*, b.empF&q as empF&yinq, b.plantsF&q as plantsF&yinq  
  from changeC as a left join l&q as b
  on a.firmid&y=b.firmid;
  create table change1A as 
  select a.*, b.empF&y as empF&qiny, b.plantsF&y as plantsF&qiny  
  from changeB as a left join l&y as b
  on a.firmid&q=b.firmid;

data change1A;
  set change1A;
  if lbdnum~="";
run;
proc sort data=change1A nodupkey;
  by lbdnum;
run;

%mend;

%oneyear2(87); %oneyear2(88); %oneyear2(89); %oneyear2(90);
%oneyear2(91); %oneyear2(92); %oneyear2(93); %oneyear2(94); %oneyear2(95); %oneyear2(96); 

%macro boughtsold;

data merger;
  set change1A;
  if firmid97="      0000" then firmid97="";
run;
%do ii=87 %to 96;
 data merger;
   set merger;
   if firmid&ii ="      0000" then firmid&ii ="";
   firmflag&ii= 0;
   mergeflag&ii =0;
run;
%end;

/* Sometimes a plants firm identifier will switch back and forth from one year to the next (i.e., it will be X in year t and t+2, 
but Y (where Y might be a missing value) in  year t+1.  This might make it seem that there are a lot more mergers and acquisitions 
than there actually are.  So, to avoid this overcounting of acquisitions, we correct the firmid so that it is X in year t+1.)  */

%do ii=88 %to 95;
%let iM2=%eval(&ii -2);
%let iM1=%eval(&ii -1);
%let iP1=%eval(&ii +1);
%let iP2=%eval(&ii +2);

data merger;
  set merger;
  if firmid&ii="" AND (firmid&iM2 ~="" OR firmid&iM1 ~="") AND (firmid&iP2 ~="" OR firmid&iP1 ~="") then firmflag&ii=2;
  if firmid&iM2 =firmid&iP1 AND firmid&iP1 ~=. AND firmid&ii ~=firmid&iM2 then firmflag&ii =1;
  if firmid&iM1 =firmid&iP1 AND firmid&iP1 ~=. AND firmid&ii ~=firmid&iM1 then firmflag&ii =1;
  if firmid&iM2 =firmid&iP2 AND firmid&iP2 ~=. AND firmid&ii ~=firmid&iM2 then firmflag&ii =1;
  if firmid&iM1 =firmid&IP2 AND firmid&iP2 ~=. AND firmid&ii ~=firmid&iM2 then firmflag&ii =1;
run;
%end;

data merger;
  set merger;
  if firmid87="" AND (firmid86~="") AND (firmid88 ~="" OR firmid79 ~="") then firmflag87=2;
  if firmid96="" AND (firmid87~="") AND (firmid95 ~="" OR firmid94 ~="") then firmflag96=2;
  if firmid86=firmid88 AND firmid86~="" AND firmid87~=firmid88 then firmflag87=1;
  if firmid86=firmid79 AND firmid86~="" AND firmid87~=firmid79 then firmflag87=1;
  if firmid94=firmid94 AND firmid94~="" AND firmid96~=firmid97 then firmflag96=1;
  if firmid95=firmid95 AND firmid95~="" AND firmid96~=firmid97 then firmflag96=1;
run;

%do ii=88 %to 96;
%let iM2=%eval(&ii -2);
%let iM1=%eval(&ii -1);
data merger;
  set merger;
  if firmflag&ii>0 AND firmflag&iM1=0 then firmid&ii=firmid&iM1;
  if firmflag&ii>0 AND firmflag&iM1>0 & firmflag&iM2=0 then firmid&ii=firmid&iM2;
run;
%end;

data merger;
  set merger;
  if firmflag87>0 & firmflag86=0 then firmid87=firmid86;
run;

%do xx=86 %to 96 ;

%let yy=%eval(&xx + 1 );

proc sort data=merger; by firmid&xx firmid&yy;
data merger; set merger; by firmid&xx firmid&yy; if first.firmid&yy then  qq=1;
proc summary data=merger; var qq; output out=counts1 (drop=_type_ _freq_) sum(qq)=qqq; by firmid&xx ;
proc sort data=merger; by firmid&yy firmid&xx;
data merger; set merger; by firmid&yy firmid&xx; if first.firmid&xx then  rr=1;
proc summary data=merger; var qq; output out=counts2 (drop=_type_ _freq_) sum(rr)=rrr; by firmid&yy ;

proc sql noprint;
   create table mergerT as 
   select a.*, b.qqq
   from merger as a left join counts1 as b
   on a.firmid&xx = b.firmid&xx ;
   create table merger as 
   select a.*, b.rrr
   from mergerT as a left join counts2 as b
   on a.firmid&yy=b.firmid&yy;
  
/* We say that an acquisition occurs if 
a) the establishment, i, changes hands between years t and t+1
b) There exists some other firm in year t that has esablishments that share the same firm identifier in year t+1 as i.

If both qqq and rrr are equal to one, it is probably the case that condition a is violated.  
If the plantsf&yy.in&xx~=. case is violated it is likely the case that condition b is violated.  
*/

data merger (drop=qq qqq rr rrr);
   set merger;
   if firmid&xx~=firmid&yy AND  firmid&xx~="" AND firmid&yy~="" AND plantsf&yy.in&xx~=. AND  (qqq~=1 | rrr~=1) then mergeflag&xx=1;  
   if firmid&xx="" OR firmid&yy="" then mergeflag&xx=.;
run; 
%end;

data soldEsts8797 (keep=mrgeyr buyer ownf lbdnum);
  set merger;
  if (mergeflag91=1 OR mergeflag92=1 OR mergeflag93=1 OR mergeflag94=1 OR mergeflag95=1 OR mergeflag96=1 OR /*
*/   mergeflag86=1 OR mergeflag87=1 OR mergeflag88=1 OR mergeflag89=1 OR mergeflag90=1) ;
  if (firmid97="" OR firmid92="") AND (firmid87="" OR firmid92="")   then delete ; 
  length buyer $10;
  length ownf $10;
  buyer="          ";
  ownf="          ";
  mrgeyr=1986;

/* Suppose the merger occurs in year t.  Then set the value of the mrgeyr variable to be t, and set the value of
 ownf (own firm) to be the firmid for that year.  Set the identity of the buying firm to be the firmid from the 
following year.  This last assignment might seem a bit funny at first, but it is the correct one: in year t. Below,
 when we look for the establishments from the buying firms, we will take the establishments that have the same firm
 identifier, in year t, that have firmid=firmid(t+1).  One thing we are missing though, is if the establishments in
 the purchasing firm have one firmid in year t and a different one in year t+1.  This could potentially explain why
 the samples from our method are smaller than the one based on the Ownership Change Database.    */

  if mergeflag87=1 then mrgeyr=1987;
  if mergeflag87=1 then buyer=firmid88; 
  if mergeflag87=1 then ownf=firmid87;
  if mergeflag88=1 then mrgeyr=1988;
  if mergeflag88=1 then buyer=firmid89; 
  if mergeflag88=1 then ownf=firmid88;
  if mergeflag89=1 then mrgeyr=1989;
  if mergeflag89=1 then buyer=firmid90; 
  if mergeflag89=1 then ownf=firmid89;
  if mergeflag90=1 then mrgeyr=1990;
  if mergeflag90=1 then buyer=firmid91; 
  if mergeflag90=1 then ownf=firmid90;
  if mergeflag91=1 then mrgeyr=1991;
  if mergeflag91=1 then buyer=firmid92; 
  if mergeflag91=1 then ownf=firmid91;
  if mergeflag92=1 then mrgeyr=1992;
  if mergeflag92=1 then buyer=firmid93; 
  if mergeflag92=1 then ownf=firmid92;
  if mergeflag93=1 then mrgeyr=1993;
  if mergeflag93=1 then buyer=firmid94; 
  if mergeflag93=1 then ownf=firmid93;
  if mergeflag94=1 then mrgeyr=1994;
  if mergeflag94=1 then buyer=firmid95; 
  if mergeflag94=1 then ownf=firmid94;
  if mergeflag95=1 then mrgeyr=1995;
  if mergeflag95=1 then buyer=firmid96; 
  if mergeflag95=1 then ownf=firmid95;
  if mergeflag96=1 then mrgeyr=1996;
  if mergeflag96=1 then buyer=firmid97; 
  if mergeflag96=1 then ownf=firmid96;
  if mrgeyr=1986 then delete;
run;
%mend;

%boughtsold;

proc sort data=soldEsts8797 out=buyerF nodupkey;
   by buyer ownf;
run;

data soldEsts8797OCD;
  set ocdFinal;
run;

%macro oneyear3(yr, suff);

%let yr1=%eval(1900+ &yr );
data sold&yr.&suff (keep=mrgeyr lbdnum buyer ownf);
  set soldEsts8797&suff ;
  if mrgeyr=%eval(&yr1) ;
run;

proc sort data=sold&yr.&suff out=two&yr.A&suff nodupkey;
   by lbdnum mrgeyr;
run;

proc sort data=sold&yr.&suff out=soldfirmsT nodupkey;
   by ownf mrgeyr buyer;
run;

proc sort data=sold&yr.&suff out=buyerfirmsT nodupkey;
   by mrgeyr buyer;
run;

data buyerFirmsT;
  set buyerFirmsT;
  if buyer~="" AND mrgeyr~=.;
run;

proc sql noprint;
   create table buyerPlants as 
   select a.lbdnum, b.buyer, b.mrgeyr
   from lbd.lbd&yr1.c as a, buyerfirmsT as b
   where a.firmid=b.buyer;

proc append base=buyerEsts8797&suff data=buyerPlants;

%mend;

%oneyear3(87,OCD); %oneyear3(88,OCD); 
%oneyear3(89,OCD); %oneyear3(90,OCD); %oneyear3(91,OCD); %oneyear3(92,OCD);
%oneyear3(93,OCD); %oneyear3(94,OCD); %oneyear3(95,OCD); %oneyear3(96,OCD);

proc export data=soldEsts8797OCD outfile="soldEsts8797OCD.csv" replace dbms = CSV;    delimiter = ','; run;
proc export data=buyerEsts8797OCD outfile="buyerEsts8797OCD.csv" replace dbms = CSV;    delimiter = ','; run;

%oneyear3(87, ); %oneyear3(88, ); %oneyear3(89, ); %oneyear3(90, ); %oneyear3(91, ); %oneyear3(92, );
%oneyear3(93, ); %oneyear3(94, ); %oneyear3(95, ); %oneyear3(96, );

proc export data=soldEsts8797 outfile="soldEsts8797.csv" replace dbms = CSV;    delimiter = ','; run;
proc export data=buyerEsts8797 outfile="buyerEsts8797.csv" replace dbms = CSV;    delimiter = ','; run;

/* This is the beginning of the second part of the .sas file.  This part puts together the datasets 
that will test the following hypothesis: acquired plants begin producing the products produced by the 
acquiring firm */

data buyerEsts;
  set buyerEsts8797;
run;
data soldEsts;
  set soldEsts8797;
run;
data buyerEstsOCD;
  set buyerEsts8797OCD;
run;
data soldEstsOCD;
  set soldEsts8797OCD;
run;

/* Unfortunately, the definitions of product codes change between CM years.  In this piece of code, I read in 
the correspondence tables and make some minor modifications.  The underlying datasets were downloaded from the Census website (appE_F, MC92NCOM) */

data prodMatching8792; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/prodMatching8792.csv" delimiter="," firstobs=2;
  length curThis $9  curBefore $9  ; 
  input curThis $ curBefore $ ;
  curThis=substr(curThis,2,7);
  curBefore=substr(curBefore,2,7);
run;
data prodMatching9297; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/prodMatching9297.csv" delimiter="," firstobs=2;
  length curThis $9  curBefore $9   ; 
  input  curThis $  curBefore $  ;
  curThis=substr(curThis,2,7);
  curBefore=substr(curBefore,2,7);
run;
proc sort data=cmf.cmf1987prod out=extra87 nodupkey; by curpc; run;
proc sort data=cmf.cmf1992prod out=extra92 nodupkey; by curpc; run;
proc sort data=cmf.cmf1997prod out=extra97 nodupkey; by curpc; run;
proc sql noprint;
  create table ext87 as 
  select a.curpc, b.curBefore
  from extra87 as a left join prodMatching8792 as b
  on a.curpc=b.curBefore;
  create table ext92 as 
  select a.curpc, b.curBefore
  from extra92 as a left join prodMatching9297 as b
  on a.curpc=b.curBefore;
  create table ext92A as 
  select a.curpc, b.curThis
  from extra92 as a left join prodMatching8792 as b
  on a.curpc=b.curThis;
  create table ext97 as 
  select a.curpc, b.curThis
  from extra92 as a left join prodMatching9297 as b
  on a.curpc=b.curThis;

/* If some products are not part of the Census-provided correspondence
(but are actually produced), then list that product in the consecutive years */

data ext87;  set ext87; if curBefore="";   
data ext92;  set ext92; if curBefore="";
data ext97;  set ext92A; if curThis="";
data ext97;  set ext97; if curThis="";
data extra87 (drop=curpc);   set ext87;  curThis=curpc;  curBefore=curpc; run;
data extra92 (drop=curpc);   set ext92;  curThis=curpc;  curBefore=curpc; run;
data extra97 (drop=curpc);   set ext97;  curThis=curpc;  curBefore=curpc; run;
data extra92A (drop=curpc);   set ext92A;  curThis=curpc;  curBefore=curpc; run;
proc append base=extra87 data=extra92A force; run;
proc append base=extra92 data=extra97 force; run;
proc sort data=extra92 nodupkey; by curThis curBefore; run;
proc sort data=extra87 nodupkey; by curThis curBefore; run;
proc append base=prodMatching8792 data=extra87 force; run;
proc append base=prodMatching9297 data=extra92 force; run;

/* Read in data from productivity supplement of the Census of Manufacturers; merge in lbdnum from the LBD dataset */
%macro oneyear4(yr);   
proc sql noprint;
   create table prod&yr.a as 
   select a.lbdnum, b.cfn, b.curpc,  b.tvs, b.pv, b.pvf, b.year, a.ind, a.fipsst, a.ar
   from cmf.cmf19&yr as a, cmf.cmf19&yr.prod as b
   where a.cfn=b.cfn;
   create table prod&yr as 
   select a.*, b.firmid, b.bestsic, b.mu
   from prod&yr.a as a, lbd.lbd19&yr.c as b
   where a.lbdnum=b.lbdnum;
%mend;

%oneyear4(87);
%oneyear4(92);
proc append base=prod87 data=prod92; 
%oneyear4(97);
proc append base=prod87 data=prod97; 

proc sql noprint;
  create table prod as
  select a.*, b.piship
  from prod87 as a left join outside.external as b
  on a.ind=b.myind AND a.year=b.year;

/* Drop observations with balancing-code products (those that begin with a "9" or end with "-" or "00", and imputed value observations */
data prod;
  set prod;
  if  substr(curpc,1,1)="9" OR substr(curpc,7,1)="-" OR pvf="I" OR substr(curpc,6,2)="00" OR lbdnum=. then delete; 
  if ar=1 then delete;  /* Drop administrative records */
  if tvs=0  OR pv<0 then delete;
run;
proc sort data=prod; by lbdnum year; run;
proc summary data=prod;
   var pv;
   output out=prod2 (drop=_type_ _freq_) sum=spv;
   by lbdnum year;
run;
proc sql noprint;
  create table prod3 as 
  select a.*, b.spv 
  from prod as a, prod2 as b
  where a.lbdnum=b.lbdnum AND a.year=b.year;
data prod ;
  set prod3;
  frac=spv/tvs;
  if frac<.5 then delete;  /* Only keep data on plants for which at least 50% of the revenues come from products for which we observe the curpc */
run;
proc sort data=prod out=vTotal; by curpc year;  run;
proc summary data=vTotal;
  var pv;
  output out=valTotal (drop=_type_ _freq_) sum=valTotal;
  by curpc year;
run;

%macro prod(yr, suff);

%let yr5= %eval(&yr+5);

data buyerThis;   /* In this marcro, This is used to denote year &yr5; Before is used to denote year &yr */ 
  set buyerEsts&suff ;
  if mrgeyr-1900 >=%eval(&yr) AND  mrgeyr-1900 <%eval(&yr5);
run;
data soldThis;
  set soldEsts&suff ;
  if mrgeyr-1900 >=%eval(&yr) AND  mrgeyr-1900 <%eval(&yr5);
run;
data prodMatchThis;  
  set prodMatching&yr.&yr5 ;
  ct=1;
run;
proc sort data=prodMatchThis; by curThis; run;
proc summary data=prodmatchThis; 
  var ct;
  output out=counts1 (drop=_type_); 
  by curThis;
run;  
proc sort data=prodMatchThis; by curBefore; run;
proc summary data=prodmatchThis; 
  var ct;
  output out=counts2 (drop=_type_); 
  by curBefore;
run;  
proc sql noprint;
  create table prodMatchTemp as 
  select a.curThis, a.curBefore,  b._freq_ as countThis
  from prodMatchThis as a, counts1 as b
  where a.curThis=b.curThis;
  create table prodMatchThis as 
  select a.*, b._freq_ as countBefore
  from prodMatchTemp as a, counts2 as b
  where a.curBefore=b.curBefore;

proc sort data=prodMatchThis nodupkey; by curThis curBefore; run;

data prodThis;  
  set prod;
  if year-1900=%eval(&yr5) ;
run;
data prodBefore;
  set prod;
  if year-1900=%eval(&yr);
run;

proc sql noprint;
  create table prodThisA as 
  select a.*, b.*
  from prodThis as a left join prodMatchThis as b
  on a.curpc=b.curThis;
  create table prodBeforeA as 
  select a.*, b.*
  from prodBefore as a left join prodMatchThis as b
  on a.curpc=b.curBefore;

data prodThis ;
  set prodThisA;
  if curThis="" then countThis=1;
  if curThis="" then curBefore=curpc;
  if curThis="" then curThis=curpc;
  curpc6=substr(curThis,1,6);
  mixweightThis=1/countThis;
  mixweightBefore=1/countBefore;
  if mixweightBefore=. then mixweightBefore=0;
run;
data prodBefore;
  set prodBeforeA; 
  if curBefore="" then countBefore=1;
  if curBefore="" then curThis=curpc;
  if curBefore="" then curBefore=curpc;
  curpc6=substr(curThis,1,6);
  mixweightThis=1/countThis;
  mixweightBefore=1/countBefore;
  if mixweightThis=. then mixweightThis=0;
run;

data prodBoth;  set prodThis; run;
proc append base=prodBoth data=prodBefore force;

proc sort data=prodBefore;
  by curpc6 lbdnum year;
run;
proc summary data=prodBefore;
   var pv;
   weight mixweightThis;
   output out=prodBefore_C6 (drop=_type_ _freq_) sum=val6;
   by curpc6 lbdnum year;  
run;

/* In year t, get the amount producded by acquiring and acquired plants */

proc sql noprint;
    create table buyer&yr as
    select a.bestsic, a.ind, a.lbdnum, a.pv as pvBuyer, a.curpc, a.firmid, b.buyer, b.mrgeyr,  a.curpc6, a.tvs, a.mu, a.curThis, a.curBefore, a.mixweightThis, a.mixweightBefore
    from prodBefore as a, buyerThis as b
    where a.lbdnum=b.lbdnum AND a.year-1900=%eval(&yr) ;
    create table sold&yr as
    select a.bestsic, a.ind, a.lbdnum, a.pv as pvOwn,  a.curpc, a.firmid,  b.buyer, b.ownf, b.mrgeyr, a.curpc6, a.tvs, a.mu, a.curThis, a.curBefore, a.mixweightThis, a.mixweightBefore
    from prodBefore as a, soldThis as b
    where a.lbdnum=b.lbdnum AND a.year-1900=%eval(&yr);

proc sort data=buyer&yr ;
  by curThis buyer mrgeyr;
run;
proc sort data=sold&yr ;
  by curThis buyer ownf  mrgeyr;
run;
proc summary data=buyer&yr ;
  var pvBuyer;
  weight mixweightThis;
  output out=buyer_&yr (drop=_type_ _freq_) sum=valBuyer;
  by curThis buyer  mrgeyr;
run;

/* Note that when computing the groups and defining the products that the acquired firm 
used to produce, that we say that the acquired firm contains only the establishments
that were actually bought by thr acquiring firm.  In other words, if there 
were four plants A, B, C, and D, and plants A and B were acquired between CM years, then
we only look at the time-t production of plants A and B (and not of A,B,C, and D). An 
analagous consideration holds in the context of destinations shipped to, instead of products
produced.  
*/

proc summary data=sold&yr;
  var pvOwn;
  weight mixweightThis;
  output out=sold_&yr (drop=_type_ _freq_) sum=valOwnFirm;
  by curThis buyer ownf  mrgeyr;
run;

proc sort data=buyer&yr ;
  by curBefore buyer mrgeyr;
run;
proc sort data=sold&yr ;
  by curBefore buyer ownf  mrgeyr;
run;
proc summary data=buyer&yr ;
  var pvBuyer;
  weight mixweightBefore;
  output out=buyer_&yr._before (drop=_type_ _freq_) sum=valBuyer;
  by curBefore buyer  mrgeyr;
run;
proc summary data=sold&yr;
  var pvOwn;
  weight mixweightBefore;
  output out=sold_&yr._before (drop=_type_ _freq_) sum=valOwnFirm;
  by curBefore buyer ownf  mrgeyr;
run;
proc sort data=buyer&yr ;
  by curpc6 buyer mrgeyr;
run;
proc sort data=sold&yr ;
  by curpc6 buyer ownf  mrgeyr;
run;
proc summary data=buyer&yr ;
  var pvBuyer;
  weight mixweightThis;
  output out=buyer_&yr._6 (drop=_type_ _freq_) sum=valBuyer_6;
  by curpc6 buyer  mrgeyr;
run;
proc summary data=sold&yr;
  var pvOwn;
  weight mixweightThis;
  output out=sold_&yr._6 (drop=_type_ _freq_) sum=valOwnFirm_6;
  by curpc6 buyer ownf  mrgeyr;
run;

/* Get plants that are present in both years */

proc sort data=prodBoth out=temp nodupkey; by lbdnum year; run;
data temp (keep=lbdnum);
  set temp;
  by lbdnum year;
  if first.lbdnum~=last.lbdnum;
  if first.lbdnum;
run;

proc sql noprint;  /* These are the plants that are in both samples */
  create table prod2Yrs as 
  select a.* 
  from prodBefore as a, temp as b 
  where a.lbdnum=b.lbdnum;

/* Merge the list of sold plants with info on the amount that 
acquired and acquiring firms were producing in the years 
before the merger */

proc sql noprint;
   create table sold&yr as 
   select a.*, b.lbdnum
   from sold_&yr as a,  soldThis as b
   where a.ownf=b.ownf AND a.buyer=b.buyer  AND a.mrgeyr=b.mrgeyr;
   create table buyer&yr as 
   select a.*, b.lbdnum
   from buyer_&yr as a, soldThis as b
   where a.buyer=b.buyer AND a.mrgeyr=b.mrgeyr;
   create table sold&yr._before as 
   select a.*, b.lbdnum
   from sold_&yr._before as a,  soldThis as b
   where a.ownf=b.ownf AND a.buyer=b.buyer  AND a.mrgeyr=b.mrgeyr;
   create table buyer&yr._before as 
   select a.*, b.lbdnum
   from buyer_&yr._before as a, soldThis as b
   where a.buyer=b.buyer AND a.mrgeyr=b.mrgeyr;
   create table sold&yr._6 as 
   select a.*, b.lbdnum
   from sold_&yr._6 as a,  soldThis as b
   where a.ownf=b.ownf AND a.buyer=b.buyer  AND a.mrgeyr=b.mrgeyr;
   create table buyer&yr._6 as 
   select a.*, b.lbdnum
   from buyer_&yr._6 as a, soldThis as b
   where a.buyer=b.buyer AND a.mrgeyr=b.mrgeyr;
   create table soldThis2Yrs as 
   select a.* 
   from soldThis as a, prod2Yrs as b
   where a.lbdnum=b.lbdnum;

/* Compute how much each plant (for all manufacturing plans) produces in two 
  subsequent CM years */

proc sort data=prodBefore; by lbdnum curpc year ind bestsic curpc6 tvs firmid; run;
proc summary data=prodBefore;
 var pv;
 weight mixweightBefore;
 output out=prodBeforeCombo (drop=_type_ _freq_) sum=value;
 by lbdnum curpc year ind bestsic curpc6 tvs firmid;
run;
data prodBeforeCombo; set prodBeforeCombo; if value>0; run;
proc sort data=prodThis; by lbdnum curpc year ind bestsic curpc6 tvs firmid; run;
proc summary data=prodThis;
 var pv;
 weight mixweightThis;
 output out=prodThisCombo (drop=_type_ _freq_) sum=value;
 by lbdnum curpc year ind bestsic curpc6 tvs firmid;
run;
data prodThisCombo; set prodThisCombo; if value>0; run;

/* Restrict, now, to the firms that were sold in between the 
 Census years */

proc sql noprint;
   create table prodSold_&yr as 
   select a.*, b.mrgeyr
   from prodBeforeCombo as a, soldThis2Yrs as b
   where a.lbdnum=b.lbdnum AND a.year-1900=%eval(&yr);
   create table prodSold_&yr5 as 
   select a.*, b.mrgeyr
   from prodThisCombo as a, soldThis2Yrs as b
   where a.lbdnum=b.lbdnum AND a.year-1900=%eval(&yr5);

/* The first two proc sorts generate lists of all the products that are made in 1997, and all of the 
   plants in the dataset.  The cross of these lists will produce the pair of product-plant pairs
   in the sample of the logit regression (corersponding to Tables A7, A9 */

proc sort data=prodSold_&yr5 out=curpcs nodupkey; by curpc; run;
proc sort data=prodSold_&yr5 out=lbds nodupkey; by lbdnum; run;
proc sort data=prodBefore out=prodBeforeAA nodupkey; by lbdnum year; run;

proc sql noprint; 
  create table full&yr5 as 
  select a.mrgeyr, a.firmid, a.lbdnum, a.bestsic, a.ind,  b.curpc, b.curpc6, a.tvs
  from lbds as a, curpcs as b;
  create table full&yr5.B as 
  select a.* ,  b.pv as valuePlant, b.mixweightThis
  from full&yr5 as a left join prodBefore as b
  on a.lbdnum=b.lbdnum AND a.curpc=b.curThis AND b.year-1900=%eval(&yr) ;
  create table full&yr5.A as 
  select a.* ,  b.mu as muBefore
  from full&yr5.B as a left join prodBeforeAA as b
  on a.lbdnum=b.lbdnum AND b.year-1900=%eval(&yr) ;
  create table full&yr5.B as 
  select a.* ,  b.val6 as valuePlant6
  from full&yr5.A as a left join prodBefore_C6 as  b
  on a.lbdnum=b.lbdnum AND a.curpc6=b.curpc6 AND b.year-1900=%eval(&yr) ;
  create table fu   ll&yr5 as 
  select a.* ,  b.valOwnFirm
  from full&yr5.B as a left join sold&yr as b
  on a.lbdnum=b.lbdnum AND a.curpc=b.curThis;
  create table full&yr5.A as 
  select a.* ,  b.valBuyer
  from full&yr5 as a left join buyer&yr as b
  on a.lbdnum=b.lbdnum AND a.curpc=b.curThis;
  create table full&yr5 as 
  select a.* ,  b.valTotal
  from full&yr5.A as a left join valTotal as b 
  on a.curpc=b.curpc AND b.year-1900=%eval(&yr5);
  create table full&yr5.A as 
  select a.* ,  b.value
  from full&yr5 as a left join prodThisCombo as b
  on  a.lbdnum=b.lbdnum AND a.curpc=b.curpc AND  b.year-1900= %eval(&yr5);
  create table full&yr5 as 
  select a.* ,  b.valBuyer_6
  from full&yr5.A as a left join buyer&yr._6 as b
  on  a.lbdnum=b.lbdnum AND a.curpc6=b.curpc6;
  create table full&yr5.A as 
  select a.* ,  b.valOwnFirm_6
  from full&yr5 as a left join sold&yr._6 as b
  on  a.lbdnum=b.lbdnum AND a.curpc6=b.curpc6;

proc append base=prodSold_&yr data=prodSold_&yr5 force;

proc sort data=prodBoth; by lbdnum year curBefore ind; run;
proc summary data=prodBoth;
   var pv;
   weight mixweightBefore;
   output out=prodBothComb (drop=_type_ _freq_) sum=value;
   by lbdnum year curBefore ind;
run;
proc sort data=prodBefore; by lbdnum year curBefore; run;
proc summary data=prodBefore;
   var pv;
   weight mixweightBefore;
   output out=prodBeforeComb (drop=_type_ _freq_) sum=valuePlant;
   by lbdnum year curBefore;
run;
data prodBothComb; set prodBothComb; if value>0;
proc sort data=soldThis2Yrs nodupkey; by lbdnum mrgeyr; run;

proc sql noprint;   
   create table prodA as 
   select a.lbdnum, a.value,  a.curBefore, a.year, a.ind, b.valBuyer
   from prodBothComb as a left join buyer&yr._before as b
   on a.lbdnum=b.lbdnum AND a.curBefore=b.curBefore;
   create table prodGroup as 
   select a.*, b.valOwnFirm
   from prodA as a left join sold&yr._before  as b
   on a.lbdnum=b.lbdnum AND a.curBefore=b.curBefore;
   create table prodA as 
   select a.*, b.valuePlant
   from prodGroup as a left join prodBeforeComb as b
   on a.lbdnum=b.lbdnum AND a.curBefore=b.curBefore AND b.year-1900=%eval(&yr);
   create table prodGroup as
   select a.*, b.piship
   from prodA as a left join outside.external as b
   on a.ind=b.myind AND a.year=b.year;
   create table prodA as 
   select a.*, b.mrgeyr
   from prodGroup as a, soldThis2Yrs as b
   where a.lbdnum=b.lbdnum;

proc export data=prodA outfile = "prodGroup&suff.&yr..csv"     replace    dbms = CSV;    delimiter = ','; run;
proc export data=full&yr5.A outfile = "prodFullSamp&suff.&yr..csv"     replace    dbms = CSV;    delimiter = ','; run;

/* The first dataset will be useful for Table 6, Panel A of the paper (well, not the OCD versions).  The second will be used to create 
 Tables A7 and A9 of the paper */

%mend;

%prod(92, );
%prod(92,OCD ); 
%prod(87, );
%prod(87,OCD ); 


/* This is the beginning of the third part of the .sas file.  This part puts together the datasets 
that will test the following hypothesis: acquired plants begin shipping to the zip codes shipped to by the 
acquiring firm */

data buyerEstsOCD;  /* The CFS was not conducted in 1987.  So, drop all establishments that were acquired before 1992 */
  set buyerEstsOCD;
  if mrgeyr>=1992;
run;
data soldEstsOCD;
  set soldEstsOCD;
  if mrgeyr>=1992;
run;
data soldEsts;
   set soldEsts;
    if mrgeyr>=1992;
run;
data buyerEsts;
   set buyerEsts;
    if mrgeyr>=1992;
run;

data cfs93A;  /* Read in the CFS */
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);   
  year=1993;
  val=value*cfs_wgt;
  rename ornl_mil=mileage value=vs;
run;

data firmlocs (keep=firmid zip5 firmDown);
  set lbd.lbd1996c;
  if emp=. OR firmid="" OR firmid="      0000" then delete;
  zip5=substr(zip,1,5)/1;     
  if zip5~=.;
  firmDown=1;
run;
proc sort data=firmlocs nodupkey; by firmid zip5;

data cfs97 (drop=dest_zip orig_zip); 
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);   
  destZ=dest_zip/1;
  origZ=orig_zip/1;
  val=vs*p_finwgt;
  stcc=sctg/1;
  year=1997;
run;

data cfs97A;
  set cfs97;
  rename origZ=orig_zip destZ=dest_zip;
run;

proc sort data=cfs97A;
  by dest_zip;
run;

proc summary data=cfs97A;
  var val;
  output out=valTotal (drop=_type_ _freq_) sum=valTotal;
  by dest_zip;
run;

proc sql noprint;
  create table cfs93 as 
  select a.cfn, a.dest_zip, b.lbdnum, b.firmid, a.year, b.bestsic, a.val, a.orig_zip, b.emp, b.mu
  from cfs93A as a, lbd.lbd1992c as b
  where a.cfn=b.cfn;
  create table cfs97 as 
  select a.cfn, a.dest_zip, b.lbdnum, b.firmid, a.year, b.bestsic, a.val, a.orig_zip, b.emp, b.mu
  from cfs97A as a, lbd.lbd1996c as b
  where a.cfn=b.cfn;

proc sort data=cfs93;    by lbdnum orig_zip;run;
proc summary data=cfs93;
  var val;
  output out=ozip93 (drop=_type_ _freq_) sum=sumval;
  by lbdnum orig_zip;
run;
proc sort data=ozip93;   by lbdnum DESCENDING sumval ; run;
data ozip93 (keep=lbdnum orig_zip);
  set ozip93;
  by lbdnum;
  if first.lbdnum;
run;
proc sort data=cfs97;    by lbdnum orig_zip;run;
proc summary data=cfs97;
  var val;
  output out=ozip97 (drop=_type_ _freq_) sum=sumval;
  by lbdnum orig_zip;
run;
proc sort data=ozip97;   by lbdnum  DESCENDING sumval; run;
data ozip97 (keep=lbdnum orig_zip);
  set ozip97;
  by lbdnum;
  if first.lbdnum;
run;

/* Merge back with CFS   */

proc sql noprint;
   create table cfs93B as 
   select a.cfn, a.dest_zip,  a.lbdnum, a.firmid, a.year, a.bestsic, a.val,    b.orig_zip, a.emp, a.mu
   from cfs93 as a, ozip93 as b
   where a.lbdnum=b.lbdnum;
   create table cfs97B as 
   select a.cfn, a.dest_zip, a.lbdnum, a.firmid, a.year, a.bestsic, a.val,    b.orig_zip, a.emp, a.mu
   from cfs97 as a, ozip97 as b
   where a.lbdnum=b.lbdnum;

proc sort data=cfs93B out=cfs93;
  by  lbdnum dest_zip orig_zip firmid year bestsic emp mu;
run;
proc sort data=cfs97B out=cfs97;
  by  lbdnum dest_zip orig_zip firmid year bestsic emp mu;
run;

/* How much does each establishment sell to each destination zip code.  
 Note that we do a sum-by bestsic emp mu just so that we retain 
 these variables for future analysis (there should be only one value
 of each of these variables per lbdnum-dest_zip pair */

proc summary data=cfs93;
  var val;
  output out=c93 (drop=_type_ _freq_) sum(val)=value;
  by lbdnum dest_zip  orig_zip firmid year bestsic emp mu;
run;
proc summary data=cfs97;
  var val;
  output out=c97 (drop=_type_ _freq_) sum(val)=value;
  by lbdnum dest_zip  orig_zip firmid year bestsic emp mu;
run;

data c93;
  set c93;
  sic4=floor(bestsic/100);
  sic3=floor(bestsic/1000);
  sic2=floor(bestsic/10000);
run;

/* Replace the 1997 bestsic for the 1993 one.  Just to make 
   merging easier  */
proc sort data=c93 out=c93S nodupkey; by lbdnum; run;

proc sql noprint;
  create table c97a as 
  select  a.firmid, a.dest_zip,  a.lbdnum, a.year, a.value,  a.orig_zip ,  b.bestsic , a.emp, a.mu
  from c97 as a left join c93S as b
  on a.lbdnum=b.lbdnum;

data c97;
  set c97a;
  sic4=floor(bestsic/100);
  sic3=floor(bestsic/1000);
  sic2=floor(bestsic/10000);
run;

/* Next we get the list of plants that are sampled in both versions of the CFS */

proc append base=cc data=c93 force;
proc append base=cc data=c97 force;
proc sort data=cc out=twoYrPlants nodupkey; by lbdnum year; run;

data twoYrPlants (keep=lbdnum);
   set twoYrPlants;
   by lbdnum;
   if first.lbdnum~=last.lbdnum;
   if first.lbdnum;
run;

%macro cfs(suff);
/* Which zip codes did the acquiring/acquired firms sell to in 1993? */

proc sql noprint;
    create table buyer93 as
    select a.lbdnum, a.sic2, a.sic3, a.sic4, a.dest_zip, a.value as vBuyer, b.buyer, b.mrgeyr
    from c93 as a, buyerEsts&suff as b
    where a.lbdnum=b.lbdnum;
    create table sold93 as
    select  a.lbdnum,  a.sic2, a.sic3, a.sic4,  a.dest_zip, a.value as vOwnFirm, b.buyer, b.ownf, b.mrgeyr
    from c93 as a, soldEsts&suff as b
    where a.lbdnum=b.lbdnum;

proc sort data=buyer93;
  by dest_zip buyer mrgeyr;
run;
proc sort data=sold93;
  by dest_zip buyer ownf  mrgeyr;
run;

proc summary data=buyer93;
  var vBuyer;
  output out=buyer_93 (drop=_type_ _freq_) sum=valBuyer;
  by dest_zip buyer  mrgeyr;
run;
proc summary data=sold93;
  var vOwnFirm;
  output out=sold_93 (drop=_type_ _freq_) sum=valOwnFirm;
  by dest_zip buyer ownf  mrgeyr;
run;

/* This macro pulls in data on the number of establishments (by firm) that exist in each 2 (or 4) digit SIC. We pull this info
  because it will be a covariate in the regressions of Table A8 and A10. */

%macro fz1(num);  

proc sort data=buyer93;
  by dest_zip buyer  mrgeyr sic&num ;
run;
proc sort data=sold93;
  by dest_zip buyer  mrgeyr ownf sic&num ;
run;
proc summary data=buyer93;
  var vBuyer;
  output out=buyer_93_&num (drop=_type_ _freq_) sum=valBuyer_&num ;
  by dest_zip buyer  mrgeyr sic&num ;
run;
proc summary data=sold93;
  var vOwnFirm;
  output out=sold_93_&num (drop=_type_ _freq_) sum=valOwnFirm_&num ;
  by dest_zip buyer  mrgeyr ownf sic&num;
run;
proc sql noprint;
   create table sold93_&num as 
   select a.*, b.lbdnum 
   from sold_93_&num as a,  soldEsts&suff as b
   where a.ownf=b.ownf AND a.buyer=b.buyer AND  a.mrgeyr=b.mrgeyr;
   create table buyer93_&num as 
   select a.*, b.lbdnum 
   from buyer_93_&num as a, soldEsts&suff as b
   where a.buyer=b.buyer AND a.mrgeyr=b.mrgeyr;
%mend;

 %fz1(2); %fz1(4); 

proc sql noprint;
   create table sold93 as 
   select a.*, b.lbdnum
   from sold_93 as a,  soldEsts&suff as b
   where a.ownf=b.ownf AND a.buyer=b.buyer  AND a.mrgeyr=b.mrgeyr;
   create table buyer93 as 
   select a.*, b.lbdnum
   from buyer_93 as a, soldEsts&suff as b
   where a.buyer=b.buyer AND a.mrgeyr=b.mrgeyr;
   create table soldEsts&suff.Both as 
   select a.* 
   from soldEsts&suff as a, twoYrPlants as b
   where a.lbdnum=b.lbdnum;

/* get plants from the 93 cfs that were purchased before 97, and are 
present in both years (the last requirement being embodied in the twoYrPlants dataset) */

proc sql noprint;
   create table cfsSold_93 as 
   select a.*, b.mrgeyr
   from c93 as a, soldEsts&suff.Both as b
   where a.lbdnum=b.lbdnum;
   create table cfsSold_97 as 
   select a.*, b.mrgeyr
   from c97 as a, soldEsts&suff.Both as b
   where a.lbdnum=b.lbdnum;

proc sort data=cfsSold_97 out=zips nodupkey; by dest_zip; run;
proc sort data=cfsSold_97 out=lbds nodupkey; by lbdnum; run;
proc sort data=c93 out=c93aa nodupkey; by lbdnum; run;

/* First we get the full cross of sender-destination_zip pairs in our sample.
  Then we merge in info about the shipments of each plant in 1993, the shipments
  of the acquired and acquiring firm, again in 1993, and the location of the merge firm's 
 establishments in 1997. By the end of this sequence of proc sql statements, we will have 
 produced the dataset that is required to produce the logit regressions */

proc sql noprint;  
  create table full97 as 
  select a.mrgeyr, a.firmid, a.lbdnum, a.bestsic, a.sic4, a.sic3, a.sic2, b.dest_zip, a.orig_zip, a.emp
  from lbds as a, zips as b;
  create table full97B as 
  select a.* ,  b.value as valuePlant
  from full97 as a left join c93 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;
  create table full97A as 
  select a.* ,  b.mu as mu93
  from full97B as a left join c93aa as b
  on a.lbdnum=b.lbdnum;
  create table full97 as 
  select a.* ,  b.valOwnFirm_2
  from full97A as a left join sold93_2 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip AND a.sic2=b.sic2;
  create table full97A as 
  select a.* ,  b.valBuyer_2
  from full97 as a left join buyer93_2 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip AND a.sic2=b.sic2;
  create table full97 as 
  select a.* ,  b.valOwnFirm_4
  from full97A as a left join sold93_4 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip AND a.sic4=b.sic4;
  create table full97A as 
  select a.* ,  b.valBuyer_4
  from full97 as a left join buyer93_4 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip AND a.sic4=b.sic4;
  create table full97 as 
  select a.* ,  b.valOwnFirm
  from full97A as a left join sold93 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;
  create table full97A as 
  select a.* ,  b.valBuyer
  from full97 as a left join buyer93 as b
  on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;
  create table full97 as 
  select a.* ,  b.valTotal
  from full97A as a left join valTotal as b
  on a.dest_zip=b.dest_zip;
  create table full97A as 
  select a.* ,  b.firmDown
  from full97 as a left join firmlocs as b
  on a.firmid=b.firmid AND a.dest_zip=b.zip5;
  create table full97 as 
  select a.* ,  b.value
  from full97A as a left join c97 as b
  on  a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;

/* Now we assemble the dataset that is used to prodce Table 6, Panel B. */

proc append base=cfsSold_93 data=cfsSold_97 force;

proc sql noprint;
   create table cfsA as 
   select a.*, b.valBuyer
   from cfsSold_93 as a left join buyer93 as b
   on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;

proc sql noprint;
   create table cfsGroup as 
   select a.*, b.valOwnFirm
   from cfsA as a left join sold93 as b
   on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;

proc sql noprint;
   create table cfsA as 
   select a.*, b.value as valuePlant
   from cfsGroup as a left join c93 as b
   on a.lbdnum=b.lbdnum AND a.dest_zip=b.dest_zip;
   create table cfsGroup as
   select a.*, b.piship
   from cfsA as a left join outside.external as b
   on a.sic4=b.myind AND a.year=b.year;
proc export data=cfsGroup outfile = "cfsGroup&suff..csv"     replace    dbms = CSV;    delimiter = ','; run;
proc export data=full97 outfile = "cfsFullSamp&suff..csv"     replace    dbms = CSV;    delimiter = ','; run;

/* The first dataset will be useful for Table 6, Panel B of the paper.  The second will be used to create 
 Tables A8 and A10 of the paper */

%mend;

%cfs( );  %cfs(OCD); 
