/* 
This .sas file pulls the necessary info for Tables 1, 2, A2, A3, and A4 of the paper.
The three data-sources that it uses are the Longitudinal Business Database (LBD),
the Census of Manufacturers (CMF), and the Commodity Flow Survey (CFS).  After 
running this program, and getdata345.sas, the user should run analysisVI.do to 
reproduce all of the figures/tables of Vertical Integration and Input Flows (with the 
exception of Tables 6, A7-A10, which require getIntangible.sas and analysisIntangible.do)

The tables that define the pairs of industries that are vertically linked, as well
as the concordance between SIC industry and the BEAs IOIND industries, were produced
by the stata do file io.do 

Throughout this file, several prefixes and suffixes show up.  Here is a brief description of these.  
two: Say that a shipment is internal according to the normal definition (sent along a vertical link).
three: Say that a shipment is internal if it is sent up an upstream plant to a zip code in which 
	there is a same-firm establishment in the firm that is downstream of *any other* plant in the firm.
	This is just for the sake of comparing to the previous, pre-2011 methodology.  See rows 8,10 of Table A2.
10/50: Use a 1 percent or 5 percent cutoff rule for defining vertically linked pairs of industries.
M2M  : Only keep manufacturing establishments, define vertical links so that only manufacturing can be downstream
       of manufacturing.  (see row 6 of Table 1B)
C    : Say all shipments are internal in which it is sent to the same county (not zip code) of a downstream establishment 
A    : Say the shipment is internal if it is sent to a zip in which *any* same-firm establishment resides. 
NH   : Never define industry I to be upstream of itself. 
Orig : Use original (pre-2011) method to define pairs of vertically linked industries.  */

libname lbd '/economic/lbd/microdata';
libname cmf '/economic/cmf.old/microdata';
libname cfs '/economic/cfs/microdata';

data lbd1 (keep=sic emp);
  set lbd.lbd1992c;
  sic=substr( bestsic, 1,4);
  if  emp~=. AND firmid~="" AND sic~=" "  AND firmid~="      0000";
run;
proc sort data=lbd1;
  by sic;
run;
proc summary data=lbd1; 
   var emp; 
   output out=sicList (drop=_type_ _freq_) sum=sumemp;
  by sic;
run; 
proc export data=sicList outfile = "sicList.csv" replace dbms = CSV; delimiter = ','; run;
run;

/* Get data on ipt and tvs from the cmf, just for 1992 and 1997 */

data cm92 (keep=ipt tvs lbdnum cfn year ind firmid);
  set cmf.cmf1992;
  year=1992;
run;
data cm97 (keep=ipt tvs lbdnum cfn year ind firmid);
  set cmf.cmf1997;
  year=1997;
run;
proc append base=cm92 data=cm97;
proc export data=cm92    outfile = "ipt9297.csv"    replace    dbms = CSV;    delimiter = ',';  run;

data sicIOmatch; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicIOmatchAlt.csv" delimiter="," firstobs=2;
  input sic4 ioind $;
run;

data sicIOmatch;
  set sicIOmatch;
  ioind=substr(ioind,2,6);
run;

data sicTable10; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable10.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTable10M2M; 
  set sicTable10;
  if sicUp>=2000;
  if sicDown>=2000;
  if sicUp<=3999;
  if sicDown<=3999;
run;

/* This next dataset removes all SIC pairs for which the upstream and downstream IOIND are the same */

data sicTable10NH; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable10NoHorz.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTable50; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable50.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

/* This next dataset removes all SIC pairs for which the upstream and downstream IOIND are the same */

data sicTable50NH; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable50NoHorz.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTableOrig; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/origTable5.csv" delimiter="," firstobs=2;
  input sicUp sicDown;
run;

data sicTable100; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable100.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTable150; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable150.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTable200; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable200.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data cfs1992A (keep=sic4 cfn year val rec_num);
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);   
  yr=1992;
  year=yr;
  mil=ornl_mil*cfs_wgt;
  rename ornl_mil=mileage value=vs;
  val=value*cfs_wgt;
  wei=weight*cfs_wgt;
  valN=0;
  if export ne "1" AND export ne "Y"  then valN=val;
run;

data cfs1997A (keep=sic4  cfn year val rec_num);
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);   
  yr=1997;
  year=yr;
  mil=mileage*p_finwgt;
  val=vs*p_finwgt;
  wei=weight*p_finwgt;
  valN=0;
  sicS=substr(sic,1,4)/1;
  sic4=floor(sicS/1);
  if export ne "1" AND export ne "Y"  then valN=val;
run;

proc sql noprint;
  create table cfs93Small as 
  select a.*, b.lbdnum, b.firmid, b.emp
  from cfs1992A as a, lbd.lbd1992c as b
  where a.cfn=b.cfn;
  create table cfs97Small as 
  select a.*, b.lbdnum, b.firmid, b.emp
  from cfs1997A as a, lbd.lbd1996c as b
  where a.cfn=b.cfn;

/* It's somewhat uncertain which version of the LBD we should be matching the CFS to.  
   While the 93 (or 97) LBD seems like the obvious version,   this leads to a lower match rate.  
   It seems as if the cfn numbers are recorded when the sample is constructed/chosen (i.e., the 
   year before).  */
  
proc export data=cfs93Small   outfile = "cfs93Small.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=cfs97Small   outfile = "cfs97Small.csv"    replace    dbms = CSV;    delimiter = ',';  run;

proc sql noprint;
  create table cfs1992 as 
  select a.*, b.ioind
  from cfs1992A as a left join sicIOmatch as b  
  on a.sic4=b.sic4;
  create table cfs1997 as 
  select a.*, b.ioind
  from cfs1997A as a left join sicIOmatch as b
  on a.sic4=b.sic4;

/* This macro will pull data on the firms that have all of their plants (or at least all of their plants within certain BEA-IOIND industry)
   sampled in a given year of the CFS.  For these plants, we will compute the total materials purchases (perhaps at the 2 or 4-digit level of
   aggregation).  The constructed datasets will be used to construct Table 2 of the paper.  */

%macro loop3(year);

%let c=c;
%let yearc=&year&c ;
%let mat=mat;
%let yearmat=&year&mat ;

/* Get data from cm and cm materials supplement */

data cm1 (keep=cfn year cp cr cf ee cw ppn); 
   set cmf.cmf&year;
run;

data cm2 (keep=cfn m mc ppn);  
  set cmf.cmf&yearmat;
  if substr(m,1,1)~="9" AND substr(m,1,1)~=" " AND mc~=.;  
/* The "9" refers to re-balancing codes (synthetic "materials" constructed by the Census ) */
run;

proc sql noprint;
   create table cm as 
   select a.*, b.*
   from cm1 as a left join cm2 as b
   on a.cfn=b.cfn;

proc sort data=cfs&year out=temp;
  by cfn ioind year sic4;
run;

proc summary data=temp;
   var val;
   output out=cfs&year (drop=_type_ _freq_) sum=value;
   by cfn ioind year sic4;
run;

data lbdB; 
  set lbd.lbd&yearc;
  sicS=substr(bestsic,1,4)/1;
  sic4=floor(sicS/1);
  gp=1;   /* Indicator variable.  Is the establishment in the goods-producing sector (i.e., can it be part of the CFS sample)? 
          When we ask "Are all of the establishments within the firm sampled in the CFS?", one might instead ask
          "Are all of the goods-producing establishments within the firm the firm sampled in the CFS?"  This is just as a potential
          robustness check, that is not reported in the paper.  */
  year=%eval(&year);
  if sic4>=5200  AND sic4~=. AND sic4~=5916 then gp=0;
  keep firmid ioind emp bestsic lbdnum cfn gp sic4 year;
  if firmid="" OR firmid="      0000"  OR emp=. OR sic4=. then delete ;
run;

proc sql noprint;
  create table lbdA as     /* Merge in IOIND codes */
  select a.*, b.ioind
  from lbdB as a left join sicIOmatch as b
  on a.sic4=b.sic4;

proc sql noprint;
  create table cm&year as 
  select a.*, b.lbdnum, b.firmid
  from cm as a, lbdA as b
  where a.cfn=b.cfn;

proc sql noprint;
   create table lbd&year as 
   select a.*, b.lbdnum , b.firmid, b.ioind as ioindLBD, b.sic4 as sic4LBD, b.gp, b.emp, b.year
   from cfs&year as a, lbdA as b 
   where a.cfn=b.cfn;

proc sort data=lbd&year out=firms nodupkey;
  by firmid;
run;

proc sql noprint;
   create table lbd1 as 
   select a.*
   from lbdA as a, firms as b
   where a.firmid=b.firmid;

proc sort data=lbd1;
  by firmid ioind;
run;

proc summary data=lbd1;
   var gp;
   output out = ct1 (drop=_type_) sum=ctLBD_GP;
   by firmid;
run;

proc summary data=lbd1;
   var gp;
   output out = ct1IO (drop=_type_ _freq_) N=ctIOIND;
   by firmid ioind;
run;

data ct1;
   set ct1;
   if _freq_>1;
run;

proc sort data=ct1 out=ct1Temp nodupkey;
    by firmid;
run;

proc sql noprint;
  create table mu as 
  select a.*
  from lbd1 as a, ct1Temp as b
  where a.firmid=b.firmid;

proc sql noprint;
   create table ct1IOIND as 
   select a.*, b._freq_
   from ct1IO as a, ct1Temp as b
   where a.firmid=b.firmid;

proc sort data=lbd&year;
  by firmid ioind;
run;

proc summary data=lbd&year;
   var emp;
   output out = ct2 (drop=_type_);
   by firmid;
run;

proc summary data=lbd&year;
   var emp;
   output out = ct2IOIND (drop=_type_);
   by firmid ioind;
run;

proc sql noprint;
  create table ctGP&year as
  select a.ctLBD_GP, a._freq_ as ctLBD, b._freq_ as ctCFS , b.firmid
  from ct1 as a, ct2 as b
  where a.firmid=b.firmid AND a.ctLBD_GP=b._freq_;
  create table ctFULL&year as
  select a.ctLBD_GP, a._freq_ as ctLBD, b._freq_ as ctCFS , b.firmid
  from ct1 as a, ct2 as b
  where a.firmid=b.firmid AND a._freq_=b._freq_;
  create table ctIOIND&year as
  select a.ctIOIND, a._freq_ as ctLBD, b._freq_ as ctCFS , b.firmid, a.ioind
  from ct1IOIND as a, ct2IOIND as b
  where a.firmid=b.firmid AND a.ctIOIND=b._freq_ AND a.ioind=b.ioind;

proc sort data=ctGP&year nodupkey;
  by firmid;
run; 
proc sort data=ctFULL&year nodupkey;
  by firmid;
run; 
proc sort data=ctIOIND&year nodupkey;
  by firmid ioind;
run; 

proc sql noprint;
  create table allInFirmPlantsFULL&year as 
  select a.*, b.cfn, b.lbdnum, b.year, b.value, b.sic4
  from ctFULL&year as a, lbd&year as b
  where a.firmid=b.firmid;
  create table allInFirmPlantsGP&year as 
  select a.*, b.cfn, b.lbdnum, b.year, b.value, b.sic4
  from ctGP&year as a, lbd&year as b
  where a.firmid=b.firmid;
  create table allInFirmPlantsIOIND&year as 
  select a.*, b.cfn, b.lbdnum, b.year, b.value, b.sic4
  from ctIOIND&year as a, lbd&year as b
  where a.firmid=b.firmid AND a.ioind=b.ioind;

%mend;

%loop3(1992);
%loop3(1997);

proc append base=allInFirmPlantsFULL1992 data=allInFirmPlantsFULL1997 force;
proc append base=allInFirmPlantsIOIND1992 data=allInFirmPlantsIOIND1997 force;
proc append base=allInFirmPlantsGP1992 data=allInFirmPlantsGP1997 force;
proc append base=cm1992 data=cm1997;

proc export data=cm1992    outfile = "materials_use.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=allInFirmPlantsFULL1992     outfile = "allInFirm_FULL.csv"    replace    dbms = CSV;    delimiter = ',';  run; 
proc export data=allInFirmPlantsIOIND1992    outfile = "allInFirm_IOIND.csv"    replace    dbms = CSV;    delimiter = ',';  run; 
proc export data=allInFirmPlantsGP1992    outfile = "allInFirm_GP.csv"    replace    dbms = CSV;    delimiter = ',';  run; 


/* Now we begin the construction of the datasets that are used for Table 1 of the paper */

data lbd1 (keep=sic4 mu firmid lbdnum emp cfn zip5 county state year);
  set lbd.lbd1992c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  if emp~=. AND firmid~="" AND firmid~="      0000";
  year=1993;
run;

data lbd1_97 (keep=sic4 mu firmid lbdnum emp cfn zip5 county state year);
  set lbd.lbd1996c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  if emp~=. AND firmid~="" AND firmid~="      0000";
  year=1997;
run;

data cfs93;
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);   
  yr=1993;
  year=yr;
  mil=ornl_mil*cfs_wgt;
  rename ornl_mil=mileage value=vs;
  val=value*cfs_wgt;
  wei=weight*cfs_wgt;
  valN=0;
  if export ne "Y"  then valN=val;
run;

proc sort data=cfs93;
  by cfn dest_zip;
run;

data cfs93a;
  set cfs93;
  by cfn dest_zip;
  newz=0;
  if first.dest_zip=1 then newz=1;
run;

data cfs97 (drop=dest_zip); 
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);   
  yr=1997;
  year=yr;
  val=vs*p_finwgt;
  wei=weight*p_finwgt;
  mil=mileage*p_finwgt;
  destZ=dest_zip/1;
  valN=0;
  if export ne "1"  then valN=val;
run;

data cfs97a;
  set cfs97;
  rename destZ=dest_zip p_finwgt=cfs_wgt;
run;

proc sql noprint;  
   create table cfs97b as 
   select a.*, b.lbdnum
   from cfs97a as a, lbd.lbd1996c as b
   where a.cfn=b.cfn;
   create table cfs93b  as 
   select a.*, b.lbdnum, b.firmid
   from cfs93a as a, lbd.lbd1992c as b
   where a.cfn=b.cfn;
   create table cfs97  as 
   select a.*, b.firmid
   from cfs97b as a left join lbd.lbd1997c as b  
   on a.lbdnum=b.lbdnum;
   create table cfs93  as 
   select a.*, b.firmid as firmid97
   from cfs93b as a left join lbd.lbd1997c as b   
   on a.lbdnum=b.lbdnum;

proc sort data=cfs97;
  by cfn dest_zip;
run;

data cfs97;
  set cfs97;
  by cfn dest_zip;
  newz=0;
  if first.dest_zip=1 then newz=1;
run;

proc sort data=cfs93;
  by cfn year;
run;

proc summary data=cfs93;
   var val valN wei mil newz cfs_wgt;
   output out=totvalue93 (drop=_type_) sum(val valN wei mil newz cfs_wgt)=totalVal domesticVal totalWeight totalMileage totalZips totalCFSwgt;
   by cfn year;
run;

data totval93;
  set totvalue93;
  rename _freq_ = ships;
run;

proc sort data=cfs97;
  by cfn year;
run;

proc summary data=cfs97;
   var val valN wei mil newz cfs_wgt;
   output out=totvalue97 (drop=_type_) sum(val valN wei mil newz cfs_wgt)=totalVal domesticVal totalWeight totalMileage totalZips totalCFSwgt;
   by cfn year;
run;

data totval97;
  set totvalue97;
  rename _freq_ = ships;
run;

proc sql noprint;
  create table totalvalue93 as 
  select a.*, b.lbdnum, b.bestsic, b.mu, b.emp, b.firmid
  from totval93 as a, lbd.lbd1992c as b
  where a.cfn=b.cfn;
  create table totalvalue97 as 
  select a.*, b.lbdnum, b.bestsic, b.mu, b.emp, b.firmid
  from totval97 as a, lbd.lbd1997c as b
  where a.cfn=b.cfn;

proc sql noprint;
  create table muCFS as 
  select a.*
  from lbd1 as a, cfs93 as b
  where a.cfn=b.cfn;
  create table muCFS_97 as 
  select a.*
  from lbd1_97 as a, cfs97 as b
  where a.cfn=b.cfn; 

/* Get firms which have at least one est. in the CFS */

proc sort data=muCFS out=firmlist nodupkey;
  by firmid;
run;

data firmlist (keep=firmid);
  set firmlist;
run;

proc sort data=muCFS_97 out=firmlist_97 nodupkey;
  by firmid;
run;

data firmlist_97 (keep=firmid);
  set firmlist_97;
run;

data zipcodelocations; 
  infile "/rdcprojects/ch/ch00573/data/zipcodes.csv" delimiter="," firstobs=2;
  input zipcode latitude longitude;
run;

/* From CM, for each of the two years get info on internal shipments */
/* Also get info on which plants are in the cfs sample */
data c1;
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);
  val=value*cfs_wgt;
  cfsamp=1;
run;

data c2;
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);
  val=vs*p_finwgt;
  cfsamp=1;
run;
proc sort data=c1;
  by cfn;
run;
proc sort data=c2;
  by cfn;
run;
proc summary data=c1;
  var val cfsamp;
  output out=cc1 (drop=_type_ _freq_) sum(val)=totalval mean(cfsamp)=cfssamp;
  by cfn;
run;
proc summary data=c2;
  var val cfsamp;
  output out=cc2 (drop=_type_ _freq_) sum(val)=totalval mean(cfsamp)=cfssamp;
  by cfn;
run;

data cmf92inta (keep=ind ipt tvs cfn lbdnum firmid);
  set cmf.cmf1992;
  if lbdnum~="";
run;
data cmf97inta (keep=ind ipt tvs cfn lbdnum firmid) ;
  set cmf.cmf1997;
  if lbdnum~="";
run;
proc sql noprint;
  create table cmf92int as 
  select a.*, b.emp 
  from cmf92inta as a, lbd.lbd1992c as b
  where a.lbdnum=b.lbdnum;
  create table cmf97int as 
  select a.*, b.emp 
  from cmf97inta as a, lbd.lbd1997c as b
  where a.lbdnum=b.lbdnum;
  create table cm92int as 
  select a.*, b.cfssamp , b.totalval
  from cmf92int as a left join cc1 as b
  on a.cfn=b.cfn;
  create table cm97int as 
  select a.*, b.cfssamp , b.totalval
  from cmf97int as a left join cc2 as b
  on a.cfn=b.cfn;

proc export data=cm92int    outfile = "cmf1992int.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=cm97int   outfile = "cmf1997int.csv"    replace    dbms = CSV;    delimiter = ',';  run;

/* First get the mu-firms that are also in the CFS */

data lbd1 (keep=sic4  mu firmid lbdnum emp cfn zip5 county state);
  set lbd.lbd1992c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  year=1992;
  if mu=1 AND emp~=. AND firmid~="" AND firmid~="      0000";
run;

/* Using the lbd, construct a mapping from 5-digit zip code to county.
For each zip code get the, county with the largest employment. 
Usually a zip code is contained in a county, so there will actually
only be one county per zp code*/

data lbdCountyMap (keep=zip5 county state emp);
  set lbd1;
  if zip5~=. AND county~="" AND state~="";
run;

proc sort data=lbdCountyMap;
  by zip5 county state;
run;

proc summary data=lbdCountyMap;
  var emp;
  output out=lbdCM (drop=_type_) sum=sumemp;
  by zip5 county state;
run;

proc sort data=lbdCM;
  by zip5 DESCENDING sumemp;
run;

data lbdMap (keep=zip5 county state);
  set lbdCM;
  by zip5;
  if first.zip5;
run;

data lbd1_97 (keep=sic4  mu firmid lbdnum emp cfn zip5 county state);
  set lbd.lbd1997c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  year=1997;
  if mu=1 AND emp~=. AND firmid~="" AND firmid~="      0000";
run;

/* Get the firms that have all of their establishments in the same county */

proc sort data=lbd1 out=lbd1_1C nodupkey;
  by firmid county state;
run;
proc sort data=lbd1_97 out=lbd1_97_1C nodupkey;
  by firmid county state;
run;
proc summary data=lbd1_1C;
  var emp;
  output out=lbd_1C (drop=_type_);
  by firmid;
run;
proc summary data=lbd1_97_1C;
  var emp;
  output out=lbd97_1C (drop=_type_);
  by firmid;
run;
data onecountyfirms92 (keep=firmid oneCountyFlag);
  set lbd_1C;
  if _freq_=1;
  oneCountyFlag=1;
run;
data onecountyfirms97 (keep=firmid oneCountyFlag);
  set lbd97_1C;
  if _freq_=1;
  oneCountyFlag=1;
run;

/* Merge back with lbd */

proc sql noprint;
  create table lbd as 
  select a.*, b.oneCountyFlag
  from lbd1 as a left join onecountyfirms92 as b
  on a.firmid=b.firmid;
  create table lbd97 as 
  select a.*, b.oneCountyFlag
  from lbd1_97 as a left join onecountyfirms97 as b
  on a.firmid=b.firmid;

/* Merge latitude and longitude info */

proc sql noprint;
  create table lbdB as 
  select a.*, b.latitude, b.longitude
  from lbd as a left join zipcodelocations as b
  on a.zip5=b.zipcode;
  create table lbd97B as 
  select a.*, b.latitude, b.longitude
  from lbd97 as a left join zipcodelocations as b
  on a.zip5=b.zipcode;

data lbd1;
  set lbdB;
  if oneCountyFlag=. then oneCountyFlag=0;
run;
data lbd1_97;
  set lbd97B;
  if oneCountyFlag=. then oneCountyFlag=0;
run;

data cfs93A (drop=sic3 sic2);
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);   
  yr=1993;
  year=yr;
  rename ornl_mil=mileage value=vs;
  val=value*cfs_wgt;
  wei=weight*cfs_wgt;
  valN=0;
  if export ne "Y"  then valN=val;
run;

data cfs97 (drop=dest_zip sic2 sic3); 
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);   
  yr=1997;
  year=yr;
  val=vs*p_finwgt;
  wei=weight*p_finwgt;
  destZ=dest_zip/1;
  rename gtrcir=grt_circ;
  valN=0;
  stcc=sctg/1;
  sic4=substr(sic,1,4)/1;
  if export ne "1"  then valN=val;
run;

/* For each plant, compute quantiles of the great circle distance of its
   shipments */

data cfs97A;
  set cfs97;
  rename destZ=dest_zip p_finwgt=cfs_wgt;
run;

proc sort data=cfs93A;
  by cfn;
run;
proc sort data=cfs97A;
  by cfn;
run;
proc summary data=cfs93A;
  var grt_circ;
  output out=pctile93 (drop=_type_ _freq_) p50(grt_circ)=grt_circ_50 p90(grt_circ)=grt_circ_90 max(grt_circ)=grt_circ_max mean(grt_circ)=grt_circ_mean;
  by cfn;
run;
proc summary data=cfs97A;
  var grt_circ;
  output out=pctile97 (drop=_type_ _freq_) p50(grt_circ)=grt_circ_50 p90(grt_circ)=grt_circ_90 max(grt_circ)=grt_circ_max mean(grt_circ)=grt_circ_mean;
  by cfn;
run;


/* Merge in destination county */

proc sql noprint;
  create table cfs93B as 
  select a.*, b.state as dstate, b.county as dcounty 
  from cfs93A as a left join lbdMap as b
  on a.dest_zip=zip5;
  create table cfs97B as 
  select a.*, b.state as dstate, b.county as dcounty 
  from cfs97A as a left join lbdMap as b
  on a.dest_zip=zip5;
  create table cfs93 as 
  select a.*, b.*
  from cfs93B as a left join pctile93 as b
  on a.cfn=b.cfn;
  create table cfs97 as 
  select a.*, b.*
  from cfs97B as a left join pctile97 as b
  on a.cfn=b.cfn;
 
proc sort data=cfs93;
  by cfn year;
run;

proc summary data=cfs93;
   var val valN wei;
   output out=totvalue93 (drop=_type_) sum(val valN wei)=totalVal domesticVal totalWeight;
   by cfn year;
run;

data totvalue93;
  set totvalue93;
  rename _freq_ = ships;
run;

proc sort data=cfs97;
  by cfn year;
run;

proc summary data=cfs97;
   var val valN wei;
   output out=totvalue97 (drop=_type_) sum(val valN wei)=totalVal domesticVal totalWeight;
   by cfn year;
run;

data totvalue97;
  set totvalue97;
  rename _freq_ = ships;
run;

proc sql noprint;
  create table muCFS as 
  select a.*
  from lbd1 as a, cfs93 as b
  where a.cfn=b.cfn;
  create table muCFS_97 as 
  select a.*
  from lbd1_97 as a, cfs97 as b
  where a.cfn=b.cfn; 

/* Get firms which have at least one est. in the CFS */

proc sort data=muCFS out=firmlist nodupkey;
  by firmid;
run;

data firmlist (keep=firmid);
  set firmlist;
run;

proc sort data=muCFS_97 out=firmlist_97 nodupkey;
  by firmid;
run;

data firmlist_97 (keep=firmid);
  set firmlist_97;
run;

/* Next get the establishments of these firms. */

proc sql noprint;
  create table cfnlist as 
  select a.*
  from  lbd1 as a, firmlist as b
  where a.firmid=b.firmid;

data cfnlist (keep=cfn lbdnum firmid sic4 emp zip5 latitude longitude state county oneCountyFlag grt_circ_50 grt_circ_90 grt_circ_max grt_circ_mean);
  set cfnlist;
run;

proc sql noprint;
  create table cfnlist_97 as 
  select a.*
  from  lbd1_97 as a, firmlist_97 as b
  where a.firmid=b.firmid;

data cfnlist_97 (keep=cfn lbdnum firmid sic4 emp zip5 latitude longitude state county oneCountyFlag grt_circ_50 grt_circ_90 grt_circ_max grt_circ_mean);
  set cfnlist_97;
run;

/* for each of these establishments, what are the downstream industries they can ship to? */

/* then, are there any downstream plants of these firms? */

/* Do this both for the new and original (bea input/output based) tables */

%macro relate(suff);

proc sql noprint;
  create table downPoss&suff as
  select a.*, b.sicDown, b.sicUp 
  from cfnlist as a, sicTable&suff as b
  where a.sic4 = b.sicUp;
  create table relationships&suff as 
  select a.*, b.cfn as cfnDown, b.lbdnum as lbdnumDown, b.emp as empDown, b.zip5 as zipDown, /*
*/  b.state as stateDown, b.county as countyDown, b.latitude as latitudeDown, b.longitude as longitudeDown 
  from downPoss&suff as a, lbd1 as b
  where a.firmid=b.firmid AND a.sicDown=b.sic4 AND a.lbdnum~=b.lbdnum;
  create table downPoss&suff._97 as
  select a.*, b.sicDown, b.sicUp 
  from cfnlist_97 as a, sicTable&suff as b
  where a.sic4= b.sicUp;
  create table relationships&suff._97 as 
  select a.*, b.cfn as cfnDown, b.lbdnum as lbdnumDown, b.emp as empDown, b.zip5 as zipDown, /*
*/  b.state as stateDown, b.county as countyDown, b.latitude as latitudeDown, b.longitude as longitudeDown 
  from downPoss&suff._97 as a, lbd1_97 as b
  where a.firmid=b.firmid AND a.sicDown=b.sic4  AND a.lbdnum~=b.lbdnum;

/* For each upstream plant, compute the distance to the plants that it is upstream of.
  Note that distances were computed slightly differently in the previous draft of the paper.
  In particular, for each upstream plant, we computed the median/10th percentile/etc. distance
  to all downstream plants of the firm (regardless of whether the industries of the upstream and downstream
  plant were vertically linked industries).  It turns out that the average distances are similar when computed 
  using the old or new methods */

data relationships2;
  set relationships&suff ;
  distance= sqrt(69.31*69.31*(latitude-latitudeDown)*(latitude-latitudeDown) + 53*53*(longitude-longitudeDown)*(longitude-longitudeDown));
run;
   
proc sort data=relationships2;
  by lbdnum;
run;

proc summary data=relationships2;
  var distance;
  output out=distances93 (drop=_type_ _freq_) p50(distance)=distance_50 p10(distance)=distance_10 min(distance)=distance_min;
  by lbdnum;
run;

data relationships2;
  set relationships&suff._97 ;
  distance=sqrt(69.31*69.31*(latitude-latitudeDown)*(latitude-latitudeDown) + 53*53*(longitude-longitudeDown)*(longitude-longitudeDown));
run;

proc sort data=relationships2;
  by lbdnum;
run;

proc summary data=relationships2;
  var distance;
  output out=distances97 (drop=_type_ _freq_) p50(distance)=distance_50 p10(distance)=distance_10 min(distance)=distance_min;
  by lbdnum;
run;

/* Who are the upstream and downstream plants? */
proc sort data=relationships&suff out=upstreamplants&suff nodupkey;
  by lbdnum;
run;
proc sort data=relationships&suff out=downstreamplants&suff nodupkey;
  by lbdnumDown;
run;
data upstreamplants2&suff (keep=firmid emp lbdnum cfn sic4 zip5 state county oneCountyFlag);
  set upstreamplants&suff ;
run;
data downstreamplants&suff (keep=firmid empDown lbdnumDown cfnDown sicDown zipDown stateDown countyDown);
  set downstreamplants&suff ;
run;

/* Do the same for 1997 */
proc sort data=relationships&suff._97 out=upstreamplants&suff._97 nodupkey;
  by lbdnum;
run;
proc sort data=relationships&suff._97 out=downstreamplants&suff._97 nodupkey;
  by lbdnumDown;
run;
data upstreamplants2&suff._97 (keep=firmid emp lbdnum cfn sic4 zip5 state county oneCountyFlag);
  set upstreamplants&suff._97;
run;
data downstreamplants&suff._97 (keep=firmid empDown lbdnumDown cfnDown sicDown zipDown stateDown countyDown) ;
  set downstreamplants&suff._97;
run;

proc sql noprint;
  create table upstreamplants3&suff as 
  select a.*, b.*
  from upstreamplants2&suff as a, totvalue93 as b
  where a.cfn=b.cfn;
  create table upstreamplants3&suff._97 as 
  select a.*, b.*
  from upstreamplants2&suff._97 as a, totvalue97 as b
  where a.cfn=b.cfn;
  create table upstreamplants&suff as 
  select a.*, b.*
  from upstreamplants3&suff as a, distances93 as b
  where a.lbdnum=b.lbdnum;
  create table upstreamplants&suff._97 as 
  select a.*, b.*
  from upstreamplants3&suff._97 as a, distances97 as b
  where a.lbdnum=b.lbdnum;

%mend;

%relate(10M2M);
%relate(10);
%relate(50);
%relate(10NH);
%relate(50NH);
%relate(Orig);   

/* Output the identities of the upstream and downstream plants */

proc export data=upstreamplants10M2M outfile = "upstreamplants10M2M.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants10M2M_97 outfile = "upstreamplants10M2M_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10M2M_97 outfile = "downstreamplants10M2M_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10M2M outfile = "downstreamplants10M2M.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants10 outfile = "upstreamplants10.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants10_97 outfile = "upstreamplants10_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10_97 outfile = "downstreamplants10_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10 outfile = "downstreamplants10.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants50 outfile = "upstreamplants50.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants50_97 outfile = "upstreamplants50_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants50 outfile = "downstreamplants50.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants50_97 outfile = "downstreamplants50_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10NH outfile = "downstreamplants10NH.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants10NH outfile = "upstreamplants10NH.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants10NH_97 outfile = "upstreamplants10NH_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplantsOrig outfile = "upstreamplantsOrig.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplantsOrig_97 outfile = "upstreamplantsOrig_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants50NH outfile = "upstreamplants50NH.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=upstreamplants50NH_97 outfile = "upstreamplants50NH_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants50NH outfile = "downstreamplants50NH.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants50NH_97 outfile = "downstreamplants50NH_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplants10NH_97 outfile = "downstreamplants10NH_97.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplantsOrig outfile = "downstreamplantsOrig.csv"replace dbms = CSV;     delimiter = ',';  run;
proc export data=downstreamplantsOrig_97 outfile = "downstreamplantsOrig_97.csv"replace dbms = CSV;     delimiter = ',';  run;

%macro combine(suff);

proc sql noprint; 
  create table one&suff  as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, a.dstate, a.dcounty, a.rec_num, b.firmid, /*
*/  a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean
  from cfs93 as a, upstreamplants&suff  as b
  where a.cfn=b.cfn;
  create table two&suff  as 
  select a.*, b.lbdnumDown, b.sicDown
  from one&suff  as a, downstreamplants&suff  as b
  where a.firmid=b.firmid AND a.dest_zip=b.zipDown;
  create table two&suff.C  as 
  select a.*, b.lbdnumDown, b.sicDown
  from one&suff  as a, downstreamplants&suff  as b
  where a.firmid=b.firmid AND a.dstate=b.stateDown AND a.dcounty=b.countyDown;
  create table two&suff.A as 
  select a.*
  from one&suff  as a, cfnlist as b
  where a.firmid=b.firmid AND a.dest_zip=b.zip5;
  create table three&suff.A as 
  select a.*, b.*
  from two&suff.A as a right join upstreamplants&suff  as b
  on a.cfn=b.cfn;
  create table three&suff  as 
  select a.*, b.*
  from two&suff  as a right join upstreamplants&suff  as b
  on a.cfn=b.cfn;
  create table three&suff.C  as 
  select a.*, b.*
  from two&suff.C  as a right join upstreamplants&suff  as b
  on a.cfn=b.cfn;
  create table one&suff  as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, b.lbdnumDown, b.sicDown, b.firmid,  /*
*/  a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean, a.dstate, a.dcounty, a.rec_num
  from cfs93 as a, relationships&suff  as b
  where a.cfn=b.cfn AND b.zipDown=a.dest_zip;
  create table two&suff  as 
  select a.*, b.*
  from one&suff  as a right join  upstreamplants&suff  as b
  on a.cfn=b.cfn;
  create table one&suff.C  as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, a.dstate, a.dcounty, /*
*/ a.rec_num, b.lbdnumDown, b.sicDown, b.firmid, a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean
  from cfs93 as a, relationships&suff  as b
  where a.cfn=b.cfn AND b.countyDown=a.dcounty AND b.stateDown=a.dstate;
  create table two&suff.C  as 
  select a.*, b.*
  from one&suff.C  as a right join  upstreamplants&suff  as b
  on a.cfn=b.cfn;

proc sql noprint;
  create table one&suff._97 as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, a.dstate, /*
 */ a.dcounty, a.rec_num, b.firmid,  a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean
  from cfs97 as a, upstreamplants&suff._97 as b
  where a.cfn=b.cfn;
  create table two&suff.C_97  as 
  select a.*, b.lbdnumDown, b.sicDown
  from one&suff._97  as a, downstreamplants&suff._97  as b
  where a.firmid=b.firmid AND a.dstate=b.stateDown AND a.dcounty=b.countyDown;
  create table three&suff.C_97  as 
  select a.*, b.*
  from two&suff.C_97  as a right join upstreamplants&suff._97  as b
  on a.cfn=b.cfn;
  create table two&suff._97 as 
  select a.*, b.lbdnumDown, b.sicDown
  from one&suff._97 as a, downstreamplants&suff._97 as b
  where a.firmid=b.firmid AND a.dest_zip=b.zipDown;
  create table two&suff.A_97 as 
  select a.*
  from one&suff._97 as a, cfnlist_97 as b
  where a.firmid=b.firmid AND a.dest_zip=b.zip5;
  create table three&suff.A_97 as 
  select a.*, b.*
  from two&suff.A_97 as a right join upstreamplants&suff._97 as b
  on a.cfn=b.cfn;
  create table three&suff._97 as 
  select a.*, b.*
  from two&suff._97 as a right join upstreamplants&suff._97 as b
  on a.cfn=b.cfn;
  create table one&suff._97 as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, a.dstate, a.dcounty, a.rec_num, /*
*/ b.lbdnumDown, b.sicDown, b.firmid, a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean
  from cfs97 as a, relationships&suff._97 as b
  where a.cfn=b.cfn AND b.zipDown=a.dest_zip;
  create table two&suff._97 as 
  select a.*, b.* 
  from one&suff._97 as a right join  upstreamplants&suff._97 as b
  on a.cfn=b.cfn;
  create table one&suff.C_97 as 
  select  a.stcc, a.vs, b.cfn, a.weight, a.cfs_wgt, a.grt_circ,  a.export, a.mileage, a.dest_zip, a.dstate, a.dcounty, /*
*/ a.rec_num, b.lbdnumDown, b.sicDown, b.firmid,  a.grt_circ_50, a.grt_circ_90, a.grt_circ_max, a.grt_circ_mean
  from cfs97 as a, relationships&suff._97 as b
  where a.cfn=b.cfn AND b.countyDown=a.dcounty AND b.stateDown=a.dstate;
  create table two&suff.C_97 as 
  select a.*, b.* 
  from one&suff.C_97 as a right join  upstreamplants&suff._97 as b
  on a.cfn=b.cfn;

proc sql noprint;
   create table upstreamplants&suff._WSTCC as 
   select a.cfn, a.firmid, b.stcc, b.vs, b.rec_num, b.cfs_wgt, b.grt_circ, b.grt_circ_50, b.grt_circ_90, b.grt_circ_max, b.grt_circ_mean
   from upstreamplants&suff as a, cfs93 as b
   where a.cfn=b.cfn;
   create table upstreamplants&suff._97_WSTCC as 
   select a.cfn, a.firmid, b.stcc, b.vs, b.rec_num, b.cfs_wgt, b.grt_circ, b.grt_circ_50, b.grt_circ_90, b.grt_circ_max, b.grt_circ_mean
   from upstreamplants&suff._97 as a, cfs97 as b
   where a.cfn=b.cfn;

%mend;

%combine(10M2M);
%combine(10);
%combine(50);
%combine(Orig);
%combine(10NH);
%combine(50NH); 

proc export data=upstreamplants10M2M_WSTCC   outfile = "upstream10M2M_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants10M2M_97_WSTCC   outfile = "upstream10M2M_97_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants10_WSTCC   outfile = "upstream10_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants10_97_WSTCC   outfile = "upstream10_97_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants50_WSTCC   outfile = "upstream50_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants50_97_WSTCC   outfile = "upstream50_97_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplantsOrig_WSTCC   outfile = "upstreamOrig_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplantsOrig_97_WSTCC   outfile = "upstreamOrig_97_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants10NH_WSTCC   outfile = "upstream10NH_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants10NH_97_WSTCC   outfile = "upstream10NH_97_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants50NH_WSTCC   outfile = "upstream50NH_WSTCC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=upstreamplants50NH_97_WSTCC   outfile = "upstream50NH_97_WSTCC.csv"    replace    dbms = CSV;   delimiter = ',';  run;

%macro getcfn(dset);

data &dset.QQ (drop=cfn firmid);
  set &dset ;
run;
proc sql noprint;
   create table &dset as 
   select a.*, b.cfn, b.firmid
   from &dset.QQ as a, lbd.lbd1992c as b
   where a.lbdnum=b.lbdnum;

data &dset.QQ (drop=cfn firmid);
  set &dset._97;
run;
proc sql noprint;
   create table &dset._97 as 
   select a.*, b.cfn, b.firmid
   from &dset.QQ as a, lbd.lbd1997c as b
   where a.lbdnum=b.lbdnum;
%mend;

%getcfn(two10M2M); %getcfn(three10M2M);
%getcfn(two10); %getcfn(two10C);   %getcfn(three10C); %getcfn(three10); %getcfn(three10A);
%getcfn(two50);  %getcfn(three50A);  %getcfn(three50);%getcfn(two50C);   %getcfn(three50C);
%getcfn(twoOrig); %getcfn(threeOrig); %getcfn(threeOrigC); %getcfn(twoOrigC); %getcfn(threeOrigA);
%getcfn(two10NH);    %getcfn(three10NHA); %getcfn(three10NH);  %getcfn(three10NHC); %getcfn(two10NHC); 
%getcfn(three50NHC);   %getcfn(three50NHA); %getcfn(three50NH);  %getcfn(two50NHC); %getcfn(two50NH);     

proc append base=two10M2M data=two10M2M_97 force;  
proc append base=three10M2M data=three10M2M_97 force; 
proc append base=two10NHC data=two10NHC_97 force;  
proc append base=two10C data=two10C_97 force;

proc append base=three10NHC data=three10NHC_97 force; 
proc append base=three10C data=three10C_97 force;
proc append base=two10 data=two10_97 force;
proc append base=three10A data=three10A_97 force;
proc append base=three10 data=three10_97 force;
proc append base=two50C data=two50C_97 force;
proc append base=two50 data=two50_97 force;
proc append base=three50A data=three50A_97 force;
proc append base=three50 data=three50_97 force;
proc append base=three50C data=three50C_97 force;

proc append base=two10NH data=two10NH_97 force;
proc append base=three10NHA data=three10NHA_97 force;
proc append base=three10NH data=three10NH_97 force;
proc append base=two50NHC data=two50NHC_97 force;
proc append base=three50NHC data=three50NHC_97 force;
proc append base=two50NH data=two50NH_97 force;
proc append base=three50NHA data=three50NHA_97 force;
proc append base=three50NH data=three50NH_97 force;
proc append base=twoOrigC data=twoOrigC_97 force;
proc append base=threeOrigC data=threeOrigC_97 force;
proc append base=twoOrig data=twoOrig_97 force;
proc append base=threeOrigA data=threeOrigA_97 force;
proc append base=threeOrig data=threeOrig_97 force;

proc export data=twoOrigC     outfile = "twoOrigC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=threeOrigC    outfile = "threeOrigC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=twoOrig     outfile = "twoOrig.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=threeOrigA    outfile = "threeOrigA.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=threeOrig    outfile = "threeOrig.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two10NH    outfile = "two10NH.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10NHA    outfile = "three10NHA.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10NH    outfile = "three10NH.csv"    replace    dbms = CSV;    delimiter = ',';  run;  

proc export data=two10    outfile = "two10.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10A    outfile = "three10A.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10    outfile = "three10.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two50    outfile = "two50.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50A    outfile = "three50A.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50    outfile = "three50.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two50C     outfile = "two50C.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50C    outfile = "three50C.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two10C     outfile = "two10C.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10C    outfile = "three10C.csv"    replace    dbms = CSV;    delimiter = ',';  run;

proc export data=two50NH    outfile = "two50NH.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50NHA    outfile = "three50NHA.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50NH    outfile = "three50NH.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two10NHC     outfile = "two10NHC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10NHC    outfile = "three10NHC.csv"    replace    dbms = CSV;    delimiter = ',';  run; 
proc export data=two50NHC     outfile = "two50NHC.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three50NHC    outfile = "three50NHC.csv"    replace    dbms = CSV;    delimiter = ',';  run;

proc export data=two10M2M     outfile = "two10M2M.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=three10M2M    outfile = "three10M2M.csv"    replace    dbms = CSV;    delimiter = ',';  run; 
proc export data=two10M2M     outfile = "two10M2M.csv"    replace    dbms = CSV;    delimiter = ',';  run;


/* For additional robustness checks, we made the cut-off (of when two industries were defined to be vertically linked)
   higher and higher (10%, 15%, 20%)  */

%relate(100);
%relate(150);
%relate(200);
%getcfn(two100); 
%getcfn(two150); 
%getcfn(two200);
%combine(100);
%combine(150);
%combine(200); 
%getcfn(two100); 
%getcfn(two150); 
%getcfn(two200); 

proc append base=two100 data=two100_97 force;
proc append base=two150 data=two150_97 force;
proc append base=two200 data=two200_97 force;

proc export data=two100    outfile = "two100.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two150    outfile = "two150.csv"    replace    dbms = CSV;    delimiter = ',';  run;
proc export data=two200    outfile = "two200.csv"    replace    dbms = CSV;    delimiter = ',';  run;


/* In the next 15 lines of code, we pull data neccessary to figure out the firm size (in terms of employment)
   This info. will be used for a robustness check of Table 1, in which we compute internal shares separately 
   for plants that are members of big, medium-sized,or small firms */

data lbd1 (keep=emp firmid);
  set lbd.lbd1992c;
  if emp~=. AND firmid~="" AND firmid~="      0000";
run;
data lbd1_97 (keep=emp firmid);
  set lbd.lbd1997c;
  if emp~=. AND firmid~="" AND firmid~="      0000";
 run;
proc sort data=lbd1; by firmid ; run;
proc sort data=lbd1_97; by firmid; run;
proc summary data=lbd1 ;       var emp;   output out =dset0    (drop=_type_ _freq_ ) sum(emp)=semp0;   by firmid;  run; 
proc summary data=lbd1_97 ;    var emp;   output out =dset0_97 (drop=_type_ _freq_ ) sum(emp)=semp0;   by firmid;  run;
proc export data=dset0 outfile="firmSizeSmall_92.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=dset0_97 outfile="firmSizeSmall_97.csv" dbms=CSV replace; delimiter = ","; run; 

/* As another robustness check, we look at which shipments have a same-firm retailer or wholesaler in the downstream zipcode
   The purpose of doing so is to compute the distribution of internal shares under the assumption that wholesalers & retailers
   are always on the downstream end of a vertical link.  */
data lbd1 (keep=sic4 mu firmid lbdnum emp cfn zip5 county state year);
  set lbd.lbd1992c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  if emp~=. AND firmid~="" AND firmid~="      0000";
  year=1992;
run;

data lbd1_97 (keep=sic4 mu firmid lbdnum emp cfn zip5 county state year);
  set lbd.lbd1997c;
  sic4=substr(bestsic,1,4)/1;
  zip5=substr(zip,1,5)/1;
  if emp~=. AND firmid~="" AND firmid~="      0000";
  year=1997;
run;

data cfs93;
  set cfs.cfs1993;
  cfn=substr(cfn,1,10);   
  yr=1993;
  year=yr;
  mil=ornl_mil*cfs_wgt;
  rename ornl_mil=mileage value=vs;
  val=value*cfs_wgt;
  wei=weight*cfs_wgt;
  valN=0;
  if export ne "Y"  then valN=val;
run;

proc sort data=cfs93;
  by cfn dest_zip;
run;

data cfs93a;
  set cfs93;
  by cfn dest_zip;
  newz=0;
  if first.dest_zip=1 then newz=1;
run;

data cfs97 (drop=dest_zip); 
  set cfs.cfs1997;
  cfn=substr(cfn,1,10);   
  yr=1997;
  year=yr;
  val=vs*p_finwgt;
  wei=weight*p_finwgt;
  mil=mileage*p_finwgt;
  destZ=dest_zip/1;
  valN=0;
  if export ne "1"  then valN=val;
run;

data cfs97a;
  set cfs97;
  rename destZ=dest_zip p_finwgt=cfs_wgt;
run;

proc sql noprint;  
   create table cfs97 as 
   select a.*, b.lbdnum, b.firmid
   from cfs97a as a, lbd.lbd1996c as b
   where a.cfn=b.cfn;
   create table cfs93  as 
   select a.*, b.lbdnum, b.firmid
   from cfs93a as a, lbd.lbd1992c as b
   where a.cfn=b.cfn;

proc sort data=cfs97;
  by cfn dest_zip;
run;

data cfs97;
  set cfs97;
  by cfn dest_zip;
  newz=0;
  if first.dest_zip=1 then newz=1;
run;

proc sort data=cfs93;
  by cfn year;
run;

data ret1 (keep=firmid zip5 sic4) ;
  set lbd1;
  if (sic4>=5000 AND sic4<=5799) OR (sic4>=5900 & sic4<6000);
run;
data ret1_97 (keep=firmid zip5 sic4) ;
  set lbd1_97;
  if (sic4>=5000 AND sic4<=5799) OR (sic4>=5900 & sic4<6000);
run;

proc sql noprint;
    create table match1 as 
    select a.*, b.sic4 as sic4D 
    from cfs93 as a, ret1 as b
    where a.dest_zip=b.zip5 AND a.firmid=b.firmid;
    create table match1_97 as 
    select a.*, b.sic4 as sic4D 
    from cfs97 as a, ret1_97 as b
    where a.dest_zip=b.zip5 AND a.firmid=b.firmid;

proc export data=match1 outfile="retailWholesale93Match.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=match1_97 outfile="retailWholesale97Match.csv" dbms=CSV replace; delimiter = ","; run;


