 /*
This .sas file pulls the neccessary info for Tables 3,4 5, A5, and A6 of the paper.
The three data-sources that it uses are the Longitudinal Business Database (LBD),
the Census of Manufacturers (CMF), and the Commodity Flow Survey (CFS).  After 
running this program, and getdata12.sas, the user should run analysisVI.do to 
reproduce all of the figures/tables of Vertical Integration and Input Flows.
 (with the exception of Tables 6 and A7-A10)
*/

libname lbd '/economic/lbd/microdata';
libname cmf '/economic/cmf.old/microdata';
libname outside '/rdcprojects/ch/ch00573/data/outside';

data sicIOmatch; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicIOmatchAlt.csv" delimiter="," firstobs=2;
  input sic4 ioind $;
run;

/* There are two small differences between sicIOmatch.csv and sicIOmatchAlt.csv.  
First, in sicIOmatchAlt.csv, all establishments in the 
construction sector (those establishments with a IOIND that begins with 11) are given an IOIND of 110000.  This is because the other 
construction industries (for example 110601) are not listed in the BEA IO Tables.

Second, there are a very small number of IOIND industries (mainly in unprocessed food) which match to multiple SIC industries.  To avoid doing
many-to-many merges, sicIOmatchAlt.csv stores only the first SIC industry for each of these IOIND industries.  

 */

data sicIOmatch;
  set sicIOmatch;
  ioind=substr(ioind,2,6);
run;

data sicTable10; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable10.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

/* This next dataset removes all SIC pairs for which the upstream and downstream IOIND are the same */

data sicTable10NH; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable10NoHorz.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTable50; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable50.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

/* This next dataset removes all SIC pairs for which the upstream and downstream IOIND are the same */

data sicTable50NH; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/sicTable50NoHorz.csv" delimiter="," firstobs=2;
  input sicUp sicDown frac;
run;

data sicTableOrig; 
  infile "/rdcprojects/ch/ch00573/Enghin/ali/origTable5.csv" delimiter="," firstobs=2;
  input sicUp sicDown;
run;

/* This macro reads in data on materials usage, which will be necessary to produce Table 2 of the paper.  
We drop balancing codes (those materials for which the first digit is a 9). */

%macro oneyear2(yr);

data cm1 (keep=ppn cp m mc year mfirstdig);
   set cmf.cmf&yr.mat;
   mfirstdig=substr(m,1,1);
   year=&yr;
   if mfirstdig="9" OR mfirstdig=" " then delete;
run;
proc append base=cmmat data=cm1;
%mend;

%oneyear2(1977);
%oneyear2(1982);
%oneyear2(1987);
%oneyear2(1992);
%oneyear2(1997);
proc export data=cmmat outfile="cmmat.csv" dbms=CSV replace; delimiter = ","; run; 

%macro oneyear(yr);

%let mat=mat;
%let c=c;
%let yrc=&yr&c;
%let yrmat=&yr&mat;

data lbd1A (keep=sic4 mu firmid lbdnum emp cfn zip5 county state);
  set lbd.lbd&yrc;
  sic4=substr(bestsic,1,4)/1;
   year=&yr;
  zip5=substr(zip,1,5)/1;
  if emp~=. AND firmid~="" AND firmid~="      0000";     
run;

data lbd2A  (keep=sic4  mu firmid lbdnum emp);
  set lbd.lbd&yrc;
  sic4=substr(bestsic,1,4)/1;
  year=&yr;
  if  emp~=. AND firmid~="" AND firmid~="      0000";
run;

proc sql noprint;
  create table lbd1 as 
  select a.*, b.ioind
  from lbd1A as a left join sicIOmatch as b
  on a.sic4=b.sic4;
  create table lbd2 as 
  select a.*, b.ioind
  from lbd2A as a left join sicIOmatch as b
  on a.sic4=b.sic4;

proc sort data=lbd2;
  by firmid ioind;
run;

data lbd2;
  set lbd2;
  by firmid ioind;
  newind=0;
  if first.ioind=1 then newind=1;
run;

proc summary data=lbd2;
  var newind emp;
  output out = firmsize (drop=_type_) sum(newind emp)=industriesFirm employmentFirm;
  by firmid;
run;

proc summary data=lbd2;
  var newind emp;
  output out = indfirmsize (drop=_type_);
  by firmid ioind;
run;

data indfirmsize;
  set indfirmsize;
  rename _freq_=establishmentsIndFirm;
run;

proc sort data=indfirmsize nodupkey;
   by firmid ioind;
run;

data firmsize2;
  set firmsize;
  rename _freq_=establishmentsFirm;
run;

data ltemp (keep=sic4 cfn lbdnum mu firmid emp);
  set lbd.lbd&yrc;
  sic4=substr(bestsic,1,4)/1;
run;

proc sql noprint;
   create table ltemp2 as 
   select a.*, b.ioind
   from ltemp as a, sicIOmatch as b
   where a.sic4=b.sic4;
   create table ltemp as 
   select a.*, b.establishmentsIndFirm
   from ltemp2 as a, indfirmsize as b
   where a.ioind=b.ioind AND a.firmid=b.firmid; 

proc sql noprint;
  create table firmsize as 
  select a.*, b.*
  from firmsize2 as a, ltemp as b
  where a.firmid=b.firmid;

data cmf (keep=year cfn lbdnum);
  set cmf.cmf&yr;
  year=&yr;
run;

proc sql noprint;
  create table muCMF as 
  select a.*
  from lbd1 as a, cmf as b
  where a.cfn=b.cfn;

/* Get firms which have at least one est. in the CMF */

proc sort data=muCMF out=firmlist nodupkey;
  by firmid;
run;

data firmlist (keep=firmid);
  set firmlist;
run;

/* Get all firms, if the year is 1997, so that we can make figure 2 */

%if %eval(&yr)>=1987 %then  %do;
  proc sort data=firmsize out=firmlistFULL nodupkey;
    by firmid;
  run;

  data firmlistFULL (keep=firmid);
    set firmlistFULL;
  run;
%end;

/* Next get the establishments of these firms. */

proc sql noprint;
  create table cfnlist as 
  select a.*
  from  lbd1 as a, firmlist as b
  where a.firmid=b.firmid;

%if %eval(&yr)>=1987 %then  %do;
proc sql noprint;
  create table cfnlistFULL as 
  select a.*
  from  lbd1 as a, firmlistFULL as b
  where a.firmid=b.firmid;
%end;

/* for each of these establishments, what are the downstream industries they can ship to? */

/* then, are there any downstream plants of these firms? */

/* Do this both for the new and original (bea input/output based) tables */

%macro relate(suff);

proc sql noprint;
  create table downPoss as
  select a.*, b.sicDown
  from cfnlist as a, sicTable&suff as b
  where a.sic4= b.sicUp;
  create table relationships as 
  select a.*, b.cfn as cfnDown, b.lbdnum as lbdnumDown, b.emp as empDown, b.zip5 as zipDown, b.sic4 as sic4Down
  from downPoss as a, lbd1 as b
  where a.firmid=b.firmid AND a.sicDown=b.sic4 AND a.lbdnum~=b.lbdnum;

proc sort data=relationships out=upstreamplants nodupkey;
  by lbdnum;
run;
proc sort data=relationships out=downstreamplants nodupkey;
  by lbdnumDown;
run;
data upstreamplants (keep=lbdnum cfn  vi emp);
  set upstreamplants;
  vi=1;
run;
data downstreamplants (keep=lbdnumDown cfnDown  vi empDown);
  set downstreamplants;
run;
data downstreamplants;
  set downstreamplants;
  rename lbdnumDown=lbdnum;
  rename cfnDown=cfn;
  rename empDown=emp;
  vi=1;
run;
proc append base=upstreamplants data=downstreamplants;
proc sort data=upstreamplants out=viplants nodupkey;
  by lbdnum;
run;

proc sql noprint;
    create table sample2 as 
    select a.vi, b.lbdnum,  b.te, b.pw,  b.fib, b.fie, b.cfn, b.ar, b.tvs , b.ind , b.ppn , b.ph , b.bae , b.mae , b.tae , b.ee , b.cm , b.sw , b.ww  , b.cp , b.cr , b.cw , b.mib , b.mie, b.ca, b.cba, b.wib, b.wie, b.cf, b.ee
    from viplants as a right join cmf.cmf&yr as b
    on a.lbdnum=b.lbdnum;
    create table sample as    
    select a.*, b.*
    from sample2 as a , firmsize as b
    where a.cfn=b.cfn; 

data sample (drop=sic4);
  set sample;
  sic42=sic4/1;
run;

data sample2 (drop=lbdnum) ;
   set sample;
   if vi=. then vi=0;
   year=&yr;
   rename sic42=sic4;
run;

proc sql noprint; 
   create table sample&suff as 
   select a.*, b.lbdnum , b.emp
   from sample2 as a, lbd.lbd&yr.c as b
   where a.cfn=b.cfn;
%mend;

%relate(Orig);
%relate(10NH);
%relate(50NH); 
%relate(50);   
%relate(10);

%if %eval(&yr)>=1987 %then  %do;

%macro relate2(suff);

proc sql noprint;
  create table downPoss as
  select a.*, b.sicDown
  from cfnlistFULL as a, sicTable&suff as b
  where a.sic4= b.sicUp;
  create table relationships as 
  select a.*, b.cfn as cfnDown, b.lbdnum as lbdnumDown, b.emp as empDown, b.zip5 as zipDown
  from downPoss as a, cfnlistFULL as b
  where a.firmid=b.firmid AND a.sicDown=b.sic4;

proc sort data=relationships out=upstreamplants nodupkey;
  by lbdnum;
run;

proc sort data=relationships out=downstreamplants nodupkey;
  by lbdnumDown;
run;

data upstreamplants (keep=lbdnum cfn vi);
  set upstreamplants;
  vi=1;
run;

data downstreamplants (keep=lbdnumDown cfnDown vi);
  set downstreamplants;
run;
data downstreamplants;
  set downstreamplants;
  rename lbdnumDown=lbdnum;
  rename cfnDown=cfn;
  vi=1;
run;

proc append base=upstreamplants data=downstreamplants;
proc sort data=upstreamplants out=viplants nodupkey;
  by lbdnum;
run;

proc sql noprint;
    create table sampleFULL as 
    select a.vi, b.*
    from viplants as a right join firmsize as b
    on a.lbdnum=b.lbdnum;

data sampleFULL;
   set sampleFULL;
   if vi=. then vi=0;
   year=&yr;
   if cfn="" then delete; 
run;

proc sort data=sampleFULL;
  by firmid DESCENDING vi;
run;

data sampleFULL2 (drop=lbdnum) ;
  set sampleFULL;
  by firmid;
  firstFirm=0;
  if first.firmid then firstFirm=1;
run;

proc sql noprint; 
  create table sampleFULL&suff as
  select a.*, b.lbdnum, b.emp
  from sampleFULL2 as a, lbd.lbd&yr.c as b
  where a.cfn=b.cfn AND b.cfn ~= "";

%mend;

%relate2(50);
%relate2(10);
%relate2(Orig);
%relate2(10NH);
%relate2(50NH); 

%end;

%mend;

%oneyear(1977);
proc append base=sampF50 data=sample50; 
proc append base=sampF10 data=sample10;
proc append base=sampFOrig data=sampleOrig;
proc append base=sampF10NH data=sample10NH;
proc append base=sampF50NH data=sample50NH;
%oneyear(1982);
proc append base=sampFOrig data=sampleOrig;
proc append base=sampF50NH data=sample50NH;
proc append base=sampF10NH data=sample10NH; 
proc append base=sampF50 data=sample50;  
proc append base=sampF10 data=sample10;
%oneyear(1987);
proc append base=sampFOrig data=sampleOrig;
proc append base=sampF10NH data=sample10NH;
proc append base=sampF50NH data=sample50NH;  
proc append base=sampF50 data=sample50;  
proc append base=sampF10 data=sample10;
proc append base=sampFF10 data=sampleFULL10;
proc append base=sampFF50 data=sampleFULL50;
proc append base=sampFFOrig data=sampleFULLOrig;
proc append base=sampFF10NH data=sampleFULL10NH;
proc append base=sampFF50NH data=sampleFULL50NH;


%oneyear(1992);
proc append base=sampFOrig data=sampleOrig;
proc append base=sampF10NH data=sample10NH;
proc append base=sampF50NH data=sample50NH;   
proc append base=sampF50 data=sample50; 
proc append base=sampF10 data=sample10;
proc append base=sampFFOrig data=sampleFULLOrig;
proc append base=sampFF10 data=sampleFULL10;
proc append base=sampFF10NH data=sampleFULL10NH;
proc append base=sampFF50 data=sampleFULL50;
proc append base=sampFF50NH data=sampleFULL50NH; 
%oneyear(1997);
proc append base=sampFOrig data=sampleOrig;
proc append base=sampF10NH data=sample10NH;
proc append base=sampF50NH data=sample50NH;  
proc append base=sampF50 data=sample50;  
proc append base=sampF10 data=sample10;
proc append base=sampFFOrig data=sampleFULLOrig;
proc append base=sampFF10 data=sampleFULL10;
proc append base=sampFF10NH data=sampleFULL10NH;
proc append base=sampFF50 data=sampleFULL50;
proc append base=sampFF50NH data=sampleFULL50NH;


/* external is a dataset that cotains info on industry-level (4-digit SIC) price indices & factor shares.  It is drawn from the NBER-CES 
   Manufacturing dataset  */

%macro relate3(suff);
proc sql noprint;
   create table sample&suff as 
   select a.*, b.iae, b.iake, b.iaks, b.ial, b.iam, b.eqrkl, b.strkl, b.piinve, b.piinvs, b.pimat, b.piship, b.nkceq, b.gkheq, b.nkcst, b.gkhst
   from sampF&suff as a, outside.external as b
   where a.ind=b.myind and a.year=b.year;

data sample (keep= mu llpr sic4 te pw ind ph sw ww year ppn firmid lbdnum cfn vi emp industriesFirm employmentFirm establishmentsIndFirm establishmentsFirm lk lkpe lpe tfp ly npwr ca cba lk llabor lm ar tvs); 
   set sample&suff ;
   if year=1997 then bae=tae*(1-iake/(iake+iaks));  /* Data on building and equipment capital stocks are missing for 1997.  
                                              Impute these variables from data on total asset holdings */
   if year=1997 then mae=tae*(iake/(iake+iaks));
   if pw>te then pw=te;      
   lm=log((cp-(mie-mib)+cr)/pimat);  
   llabor=log(ph*sw/ww);
   kseq=mae*(nkceq/gkheq); 
   ksst=bae*(nkcst/gkhst);
   le=log((cf+ee)/pimat);
   lk=log(kseq+ksst); lmk=log(kseq); lbk=log(ksst);
   lkpe=lk-llabor;  
   npwr=(te-pw)/te;
   sic3=floor(sic4/10);
   sic2=floor(sic4/100);
   ly=log((tvs+fie-fib+wie-wib)/piship); 
   tfp=ly-ial*llabor-iam*lm-iae*le-(iake+iaks)*lk;
   lpe=ly-log(te); lph=ly-llabor;
run;

proc sql noprint;
  create table sample&suff as 
  select a.*, b.ioind
  from sample as a left join sicIOmatch as b
  on a.sic4=b.sic4;
%mend;

%relate3(Orig);
%relate3(10NH);
%relate3(50NH); 
%relate3(50); 
%relate3(10);

proc export data=sample50 outfile="table5to7_50.csv" dbms=CSV replace; delimiter = ","; run; 
proc export data=sample10 outfile="table5to7_10.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sampleFF50 outfile="fig2_50.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sampFF10 outfile="fig2_10.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sampleOrig outfile="table5to7_Orig.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sample10NH outfile="table5to7_10NH.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sample50NH outfile="table5to7_50NH.csv" dbms=CSV replace; delimiter = ","; run; 
proc export data=sampFFOrig outfile="fig2_Orig.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sampleFF10NH outfile="fig2_10NH.csv" dbms=CSV replace; delimiter = ","; run;
proc export data=sampleFF50NH outfile="fig2_50NH.csv" dbms=CSV replace; delimiter = ","; run; 
 