/*

This do-file produces the definitions of vertically linked inudstries.  
The strategy to do so is as follows:
   A) Figure out how much  of each commodity (STCC code) is consumed by each 4 digit SIC
   B) Aggregate over the different STCC codes that an upstream industry (4-digit SIC) produces to get 
     a table of upstream-downstream 4-digit industries.
   C) Keep only upstream-downstream pairs if the fraction of the upstream's sales that go to the downstream industry
     are greater than some threshhold (say 1%, 5%, etc...)
Part "A" has many component parts, which differ depending on the sector of the downstream industry (if it is in wholesale, retail, or some other sector)
   --If the downstream industry, j, is in wholesale, then we use data on the CFS (which tells us how much of each commodity (STCC) code the industry ships,
      and then use info from the AWTS (which gives the ratio of purchases to shipments) to back out the amount that each wholesale industry purchases.
   --If j is in retail, we use the ARTS.  The ARTS tells us how much each SIC purchased in total.  To back out how much j purchased of each commodity 
        we use a (somewhat arbitrary) classification of IOIND commodities that can potentially be purchased by each retail SIC.  
   --If j is in any other industry, we use the "use" table.  For any IOIND commodity, there is an 1:n mapping (which we will construct) to STCC codes.
         We then match the BEA's use table (which tells us how much a given BEA IOIND industry uses each BEA commodity.  Using the aforementioned mapping, 
         we can back out how much each IOIND industry uses each STCC commodity.  Then, using another matching of IOIND industries to SIC industries, we
         can infer how much each SIC industry, j, used of each commodity.  The presumption that we make is that, within an IOIND industry, purchases of each 
         commodity made by a given SIC industry are proportional to employment.  
   Why don't we just use the BEA for the cases in which j is in retail/wholesale?  There are two problems.  First, the Input-Output Tables are very coarse 
     for the retail/wholesale case (there is just one industry, according to the classification, for each of the two sectors.  So, if an potential upstream 
     industry i (for example auto manufacturers) is classified as vertically linked to wholesale, it will be classified as upstream of not only auto wholesalers,
     but also furniture (or foodstuffs) wholesalers.  Second, the Input-Output Tables do not record the gross flows of shipments, but instead the fraction of
     output from industry i that is used as an input in the production of wholesale/retail services.  For example, one of the major input suplliers to
     wholesale is the wood pallets industry, even though shipments of foodstuffs dwarf the value of shipments of wood pallets to wholesalers.  Since we
     are interested in the value of the gross shipments to/from wholesalers and retailers, the BEA's measurements are inappropriate, for our purposes.  

The do file takes in the following datasets 
   --retail_sales and retail_purchases are slightly cleaned versions of data from the ARTS
   --wholesale_purchase is taken from the AWTS (using data on wholesalers that are neither Merchant Wholesalers nor ManufacturingSales Branches or Offices
   --cfsFull the 1993 Commodity Flow Survey, taking the sample of shipments for which the upstream plant could be 
        matched to the 1992 LBD (so that we can get the firmid of the upstream plant)
   --sicList gives data on the employment in each 4-digit sic code (it was computed from the 1992 LBD) 
   --stcccodes.csv gives a correspondence between stcc codes and sic codes (and is made available by us)
   --the 1992 Use table, downloaded from the BEA. 
   --the 1987 Make and Use tables (this is only for the robustness check comparing the newer methodology to the methodology 
        used in an earlier (pre-2011) version of this paper.  

The do file calls three other do files
   --doioindsic.do : fills in the correspondence between the BEA's industry code (IOIND) and sic codes 
        (the correspondence can be found, in its original form, on the BEA's website
   --doioindRet.do : what are the retail industries (sic industries between 5400 and 5999, not including 5800-5899) 
        that can potentially purchase any given commodities (according to the BEA definition of commodities).  
   --doioindCon.do : what are the construction industries (industries between 1700 and 1799) 
        that can potentially purchase any given commodities (according to the CFS definition of commodities).  
  
*/

clear
clear matrix
set more off

insheet using sicList.csv, clear 
ren sic sic4
save sicList, replace

use vs cfs_wgt stcc using cfsFull, replace
gen vs2=vs*cfs_wgt
collapse (sum) vs2, by(stcc)
ren vs2 vs
save stccvals, replace

/*  For the next 50 or so lines, we are going to be cleaning two dataasets taken from the ARTS 
(one on purchases, and one on sales).  */

insheet using ../../data/outside/retail_sales.csv, clear  
replace sales=regexr(sales,",","")  
/* Remove commas in the expressions of sales (for example replace 3,281 with 3281) */
replace sales=regexr(sales,",","")
replace sales=regexr(sales,",","")
destring sales, replace
drop if naics==4521 | naics==45211 | naics==. | floor(naics/100)==72 | floor(naics/10)==72  
/* The two "452" industries are department stores, which are duplicate info (there are industries called 452111 (discount dept. sores) and 452112 (nondiscount department stores) which we will be using, instead) */
drop if naics==722211 | naics==72231 /* Drop a few industries for which data on purchases do not exist */
sort naics year sales
by naics year: keep if _n==_N  
save retsales, replace

insheet using ../../data/outside/retail_purchases.csv, clear
replace purchases=regexr(purchases,",","")
replace purchases=regexr(purchases,",","")
replace purchases=regexr(purchases,",","")
destring purchases, replace
drop if naics==4521 | naics==45211 | naics==.  
save retpurcha, replace

use retpurcha 
merge 1:1 nai year using retsales
tostring na, replace force
replace nai=nai+"-" if length(naics)<6    
/* Make sure that each NAICS code has 6 digits, by adding dashes */
replace nai=nai+"-" if length(naics)<6
replace nai=nai+"-" if length(naics)<6
replace nai=nai+"-" if length(naics)<6
gen frac=pur/sales   
drop _merge
sort year naics  
/* There are some retail industries for which we have info on sales, but not purchases.  To impute purchases, for these industries, we assume that the ratio of purchases to sales is the same 
          within the next largest category of retail industires.  For example, the ratio of purchases to sales for industry 44112- and 44111- is assumed to be the same as that as the ratio in the industry 4411-- */
replace frac=frac[_n-1] if naics_code=="44111-" | naics_code=="44112-" | (substr(naics,1,3)=="442" & frac==.) | (substr(naics,1,3)=="443" & frac==.) | naics=="44511-" | naics=="45111-" | naics=="45112-"  | (substr(naics,1,3)=="453" & frac==.) | naics=="44412-" | naics=="44413-"  
replace purchases=sales*frac if purchases==. & frac~=.
replace purchases=purchases[_n-4]-purchases[_n+1]-purchases[_n-3] if naics=="4412--"  
/* In these cases, we know the total purchases in the larger subcategory and some (but not all) smaller category industries.  We take the 
                                                                                       difference, to figure out the purchases in the remaining smaller category industries.  */
replace purchases=purchases[_n-3]-purchases[_n+1]-purchases[_n-2] if naics=="4452--"
replace purchases=purchases[_n-7]-purchases[_n-1]-purchases[_n-6] if naics=="4483--"
replace purchases=purchases[_n-4]-purchases[_n-3] if naics=="4512--"
replace purchases=(purchases[_n-2]-purchases[_n-1])*sales/(sales+sales[_n+1]) if naics=="4542--"
replace purchases=(purchases[_n-3]-purchases[_n-2])*sales/(sales+sales[_n-1]) if naics=="4543--"
replace frac=pur/sales if frac==. & purchases~=.
replace frac=frac[_n-1] if naics=="45121-" | naics=="451211" | naics=="44831-" | naics=="45431-"
replace purchases=sales*frac if purchases==. & frac~=.
drop frac sales
sort year nai
replace kind=substr(kind,1,30)
outsheet using retail_purchase.csv, delim(,) replace  

/* For each stcc count the best wholesaler/retailer & manufacturer/miner */

use vs cfs_wgt sic4s export stcc using  cfsFull, replace
keep if export =="N"
drop export
gen sic=floor(sic4/100)   
drop if sic==.
drop sic4s
gen value=vs*cfs_wgt  
gen valueW=value if sic>=5000  
replace valueW=0 if valueW==.
gen valueM=value if sic<5000
replace valueM=0 if valueM==.             
/* For each commodity (STCC) we will compute the amount sent by wholesalers.  
            We will then keep the industry-commodity pairs for which at least some fraction of the value of the commodity is sent by the particular wholesale
           industry.  This is mainly to keep the computation burden low (we will be doing a bunch of joins which means that the number of observations can 
           get out of hand pretty easily ; industry-commodity pairs with low fvalW won't affect
           the final definitions (over which industry-pairs are defined to be vertically related), anyway).    */
bysort stcc sic: egen svalW=sum(valueW)
by stcc sic: egen svalM=sum(valueM)
by stcc: egen totval=sum(value)
gen fvalW=svalW/totval
gen fvalM=svalM/totval
by stcc sic: keep if _n==1
drop if max(fvalW, fvalM)<.00001
drop vs cfs_wgt value*
save temp, replace 

use temp, replace
keep if fvalW~=0 
drop fvalM svalM 
gsort stcc -fvalW
by stcc: gen rk=_n
keep if fvalW>.005
ren sic sic4
drop if sic4>=5200
save topwhole, replace

insheet using stcccodes.csv, clear  /* Create a correspondence of the pairs of stcc commodity codes that can be matched to the BEA industry codes. */
drop sctg f4
bysort sic stcc: keep if _n==1
ren sic sic4
gen sic3=floor(sic4/10)
gen sic2=floor(sic4/100)
gen ioind=""
qui do doioindsic 
drop sic3 sic2 
save stccIOmatch, replace  

insheet using sicList.csv, delim(,) clear
ren sic sic4
gen sic3=floor(sic4/10)
gen sic2=floor(sic4/100)
gen ioind="";
qui do doioindsic
drop sic3 sic2 
drop if ioind==""
drop if ioind=="690100" | ioind=="690200" 
 /* Drop wholesale and retail.  Here, we don't rely on the correspondence provided by the BEA 
   Their correspondence is just way to coarse to be useful for us (all SIC industries with SIC2=50 or 51 are given 1 IOIND classification, for example)  */
save stcclist, replace

insheet using ../../data/outside/bea_use_87_02.csv, clear
keep if year==1992
gen id=_n
destring use, replace force
replace use=use*1e6
ren indusry industry
replace industry="110000" if substr(industry,1,2)=="11" & substr(industry,1,4)~="1106"  & substr(industry,1,4)~="1104"
replace commodity="0"+commodity if length(commodity)<6  /* Make sure all commodity/industry codes have length 6 */
replace industry="0"+industry if length(industry)<6
drop if substr(industry,1,1)=="9"  /* These are not really industries (they are exports/final consumption/ etc... */
bysort commodity: egen totuse=sum(use)   
gen frac=use/totuse
keep if frac>.0001  
/* This is just to speed up the computation.  We will be doing a few joins and things slow down a lot without this command.
                     Removing these super-low "frac" industry-pairs will not change the final definitions of which 
                     industries are classified as vertically linked. */
ren commodity ioind
joinby ioind using stccIOmatch
bys id ioind stcc: keep if _n==1
save tempC, replace
drop sic4
ren ioind commodity 
ren industry ioind 
joinby ioind using stcclist
ren ioind industry
order stcc sic
keep stcc sic frac use id
save tempB, replace

insheet using ../../data/outside/bea_use_87_02.csv, clear  
keep if year==1992
gen id=_n
destring use, replace force
replace use=use*1e6
replace retail=retail*1e6
ren indusry industry
replace industry="110000" if substr(industry,1,2)=="11" & substr(industry,1,4)~="1106" & substr(industry,1,4)~="1104"
replace commodity="0"+commodity if length(commodity)<6
replace industry="0"+industry if length(industry)<6
drop if substr(industry,1,1)=="9" & substr(industry,1,2)~="91"
bysort commodity: egen totuse=sum(use)
by commodity: egen totret=sum(retail)
gen frac=totret/totuse    /* frac, here, is the retail margin, as recordd in the IO table.  We are going to keep only the commodities that are 
                             prone to be sold to retailers.  The frac>.005 removes roughly half of the commodities.  To give some indication of this 
                             restriction, note that the (publically available) BEA tables tell us that paperboard boxes are not sold at retailers, but 
                             surgical instruments are; these are the two IOIND commodities on either side of the 0.5% cutoff. */  
by commodity: keep if _n==1
keep if frac>.005  
keep commodity frac totuse
replace commodity="0"+commodity if length(commodity)<6
sort commodity
do doioindRet.do  /* We manually assign commodities to the SIC industries that could potentially sell this commodity" */
gen group=1
joinby ioind using stccIOmatch
drop sic4
ren sic sic4
bysort stcc sic: keep if _n==1
save stccRet, replace

append using tempB  /* Remember tempB is the correspondence between STCC commodities and non-wholesale/retail SIC industries */
replace group=2 if group==.
append using topwhole
replace group=3 if group==.
replace frac=fvalW if group==3
gsort stcc sic4 -frac
keep frac-stcc use id
order stcc sic4 group frac
do doioindCon  /* Remove, in a fairly conservative manner, the stcc-construction SIC combinations for which we have a prior that no shipments could occur. 
                 For example, establishments in the glass and glazing work industry probably purchases little-or-no Portland cement.  We rule out things like this */
outsheet using ioTable.csv, delim(,) replace    

/* At this point, ioTable contains a very large number of industry pairs.  We will now need to pare this down, according to some cutoff rules
                                                 (namely that the flows of shipments from i to j represent some fraction of i's total shipment value).  But we still don't know (when j is 
                                                  wholesale or retail or construction) how much flows from i to j.  This is the main task of the remainder of the do-file */
use sicList, replace
qui sum sumemp if floor(sic4/100)==15 | sic4==1799 | sic4==6552 | sic4==1700   
/* There are two types of construction industries, general vs specialized.  We classify 
                                                                                construction along these lines, and then compute the fraction of employment in these two 
                                                                               types of construction industries.  We do so, in order to eventually assign values of shipment flows
                                                                               from upstream industries to downstream (construction) industries.
                                                                               We make this distinction, between general and specialized, because we have pared down the possible 
                                                                               pairs of industries (only if j is pecialized) that we think can be vertically linked (in doioindCon.do) For example,
                                                                               we throw out i=glass manufacturers and j=electrical construction, presuming that electrical construction
                                                                               does not use glass as an input.  */
local gen = r(sum)
qui sum sumemp if floor(sic4/100)==17 & sic4~=1799 & sic4~=1700
local spe = r(sum)
local fraS=`spe'/(`spe'+`gen')
insheet using ioTable.csv, clear
drop if floor(sic4/1000)==5 & floor(sic4/100)~=58
merge n:1 sic using sicList
tab _merge 
drop if _merge<3
drop _merge
merge n:1 stcc using stccvals
drop if _merge<3
drop _merge
bysort id stcc: egen s1=sum(sumemp)
bysort id sic4: egen s2=sum(vs)
gen useA=use*sumemp*vs/s1/s2                
replace useA=. if floor(sic4/100)==15 | floor(sic4/100)==17 | sic4==6552
gen grA=1 if  floor(sic4/100)==15 | sic4==1799 | sic4==6552 | sic4==1700  /* grA=1 (gr is short for group) for the general construction industries, and = 2 for the specialized construction industries */ 
replace grA=2 if floor(sic4/100)==17 & sic4~=1799 & sic4~=1799
bysort id: egen mxA=max(grA)
gen useC=use if mxA==1 & grA==1
replace useC=use*`fraS' if mxA==2 & grA==2
replace useC=use*(1-`fraS') if mxA==2 & grA==1
bysort id stcc grA: egen s1C=sum(sumemp)
bysort id sic4 grA: egen s2C=sum(vs)
gen useCC=useC*sumemp*vs/s1C/s2C
replace useA=useCC if useCC~=.
keep stcc sic4 useA sumemp
save othT, replace

insheet using wholesale_purchase.csv, clear
replace s=s*1e6
replace purchase=purchase*1e6
gen frac2=purchase/(s+purchase)
gen gr=1 if substr(naics,1,3)=="423" & frac~=.
replace gr=2 if substr(naic,1,3)=="424" & frac~=.
qui sum frac2 [aw=pur] if gr==1
replace frac2=r(mean) if naics=="423---"
qui sum frac2 [aw=pur] if gr==2
replace frac2=r(mean) if naics=="424---"
keep if frac2~=.
keep naics frac2
gen sic4="5000 5099" in 1/1                                /* Manually merge the 1997 NAICS groupings (using in the AWTS) to the corresponding 4-digit SIC industries */
replace sic4="5010 5012 5013 5014 5015" in 2/2
replace sic4= "5020 5021 5023" in 3/3
replace sic4= "5030 5031 5032 5033 5039" in 4/4
replace sic4= "5040 5043 5044 5045 5046 5047 5048 5049" in 5/5
replace sic4= "5050 5051 5052" in 6/6
replace sic4= "5060 5063 5064 5065 " in 7/7
replace sic4= "5070 5072 5074 5075 5078" in 8/8
replace sic4= "5080 5082 5083 5084 5085 5087 5088" in 9/9
replace sic4= "5090 5091 5092 5093 5094" in 10/10
replace sic4= "5100 5199" in 11/11
replace sic4= "5110 5111 5112 5113" in 12/12
replace sic4= "5120 5122" in 13/13
replace sic4= "5130 5131 5136 5137 5139" in 14/14
replace sic4= "5140 5141 5142 5143 5144 5145 5146 5147 5148 5149" in 15/15
replace sic4= "5150 5153 5154 5159 5191" in 16/16
replace sic4= "5160 5162 5169" in 17/17
replace sic4= "5170 5171 5172" in 18/18
replace sic4= "5180 5181 5182" in 19/19
replace sic4= "5190 5192 5193 5194 5198" in 20/20

forvalues x=1/15 {
  gen sic_`x'=word(sic4, `x')  /* Generate a list of variables, which give a mapping of NAICS codes to SIC codes */
}
drop sic4
reshape long sic_, i(frac2) j(n)
drop if sic==""
destring sic, replace force
ren sic_ sic4 
drop naics
drop n 
save whoMargins, replace
use topwhole
joinby sic4 using whoMargins
gen useA=svalW*frac
joinby sic4 using sicList
keep stcc sic4 useA sumemp
save whoT, replace

insheet using retail_purchase.csv, clear
replace pur=pur*1e6
keep if year==1992  /* Here we use data from 1992 because we are going to match with the 1992 BEA I-O Table */

/* The dataset contains many "levels" of aggregation of different retail industries.  In the next
five lines we drop the levels that we don't use.  To give an example 4411 is "Car Dealers", which contains
44111 "New Car Dealers" and 44112 "Used Car Dealers."  We will delete 4411 from our dataset here, because 
we can map "New Car Dealers" to SIC industries 5510-5519 (also the grab-bag industries 5500 and 5599)
 and "Used Car Dealers" to SIC industries 5520-5529 */ 

drop if naics=="4411--" | naics== "441---"| naics=="442---"| naics=="44221-"| naics=="44229-"| naics=="442299"| naics=="443---"| naics=="44311-"
drop if naics=="443112"| naics=="44312-"| naics=="4441--"| naics=="44412-"| naics=="44413-"| naics=="445---"| naics=="44511-"| naics=="446---"
drop if  naics=="448---"| naics=="44811-"| naics=="44812-"| naics=="44814-"| naics=="44819-"| naics=="451---"| naics=="45111-"
drop if naics=="451211"| naics=="452111"| naics=="452112"| naics=="4529--"| naics=="45291-"| naics=="45299-"| naics=="453---"
drop if naics=="45399-"| naics=="4542--" | naics=="443111" | naics=="44611-" | naics=="45121-" | naics=="4532--" | naics=="45112-"

gen sic4="5500 5510 5511 5599" in 1/1
gen purchA=purchases
replace purchA=purchases+purchases[_n+1] in 9/9  /* Combine "Grocery Stores" and "Specialty Food Stores"  */
replace purchA=purchases-purchase[_n+1] in 16/16  /* Separate out "Jewelry Stores" from "Jewelry, Luggage, and Leather Stores" */
replace purchA=purchases-purchase[_n+1] in 28/28   /* Separate out "Fuel Dealers from "Direct selling establishments" */
replace sic4="5520 5521" in 2/2
replace sic4="5550 5551 5560 5561 5570 5571" in 3/3
replace sic4="5530 5531" in 4/4
replace sic4="5700 5710 5712" in 5/5
replace sic4="5713 5714 5719" in 6/6
replace sic4="5720 5722 5730 5731 5734" in 7/7
replace sic4="5200 5210 5211 5230 5231 5250 5251 5260 5261 5270 5271 " in 8/8
replace sic4="5400 5410 5411 5420 5421 5422 5423 5430 5431 5440 5441 5450 5451 5460 5461 5462 5463 5490 5499" in 9/9
replace sic4="5920 5921" in 11/11
replace sic4="5949 5600 5610 5611 5621 5630 5632 5641 5650 5651 5699" in 14/14
replace sic4="5660 5661" in 15/15
replace sic4="5540 5541" in 13/13
replace sic4="5910 5911 5912" in 12/12
replace sic4="5948" in 16/16
replace sic4="5944" in 17/17
replace sic4="5941 5945 5946 5940" in 18/18
replace sic4="5736 5735 5942 5994 5993 " in 19/19
replace sic4="5300 5310 5330 5390 5311 5380 5331 5399" in 20/20
replace sic4="5992" in 21/21
replace sic4="5943" in 22/22
replace sic4="5947" in 23/23
replace sic4="5930 5931" in 24/24
replace sic4="5999 5990 5995" in 25/25
replace sic4="5960 5961 5962" in 27/27
replace sic4="5963" in 28/28
replace sic4="5980 5983 5984 5989" in 29/29
drop in 26/26
drop in 10/10

forvalues x=1/25 {
  gen sic_`x'=word(sic4, `x')     
}
drop sic4 kind purchases
reshape long sic_, i(purchA) j(n)
drop if sic==""
destring sic, replace force
ren sic_ sic4 
drop naics n
sort purchA
by purchA: gen group2=1 if _n==1
gen group=sum(group2)
drop group2 
sort sic

joinby sic4 using sicList
bysort group: egen s2=sum(sumemp)
gen purchB=purchA*sumemp/s2
keep year purchB sic4 sumemp
sort sic4
save retPur, replace

use stccRet, replace
keep stcc sic4 
joinby sic4 using retPur
merge n:1 stcc using stccvals
bys sic4 stcc year: keep if _n==1
bysort sic4: egen s2=sum(vs)
gen useA=purchB*vs/s2
drop if _merge==2
drop vs s2 purchB _merge year
gen groupA=4
save retT, replace
append using whoT
replace groupA=3 if groupA==.
append using othT
replace groupA=1 if groupA==.
gen useper=useA/sumemp
collapse (sum) useA (sum) useper (mean) groupA (mean) sumemp, by(sic4 stcc)
sort stcc
by stcc: egen f=sum(useA)
gen frac=useA/f
keep if frac>.0005
save ioTtemp, replace

/* Collapse everything down to SICUP -> SICDOWN */
use vs cfs_wgt sic4s export stcc using  cfsFull, replace
keep if export =="N" 
drop export
gen sicUp=floor(sic4/100)
drop if sicUp==.
drop sic4s
gen value=vs*cfs_wgt
collapse (sum) value, by(sicUp stcc)
bys stcc: egen totvalue=sum(value)
gen fvalue=value/totvalue
keep if fvalue>.0005
save sicVals, replace
joinby stcc using ioTtemp
gen flow=value*frac

bys sicUp: egen sumflow=sum(flow)
gen fraction=flow/sumflow
collapse (sum) flow (min) sumflow, by(sic4 sicUp)

preserve
drop sumflow  
sort sic4
by sic4: egen sumflow=sum(flow)
gen frac=flow/sumflow
keep frac flow sic4 sicUp
keep if frac>.001
save ioT_down, replace
restore

gen frac=flow/sumflow    /* Output definitions of vertically linked industries, using different cutoffs */
keep sicUp sic4 frac 
keep if frac>=.001   
save sicTable01, replace  /* The numbers in the suffic refer to thousandths (so sicTable200.csv, keeps all industry-pairs for which the seller makes up at least 200/1000 of its sales) */
outsheet using sicTable01.csv, replace delim(,)
keep if frac>=.005   
save sicTable05, replace
outsheet using sicTable05.csv, replace delim(,)
keep if frac>=.01   
save sicTable10, replace
outsheet using sicTable10.csv, replace delim(,)
keep if frac>=.05   
save sicTable50, replace
outsheet using sicTable50.csv, replace delim(,)
keep if frac>=.10   
save sicTable100, replace
outsheet using sicTable100.csv, replace delim(,)
keep if frac>=.15   
save sicTable150, replace
outsheet using sicTable150.csv, replace delim(,)
keep if frac>=.20   
save sicTable200, replace
outsheet using sicTable200.csv, replace delim(,)

/* For the sake of comparison make tables from the original paper */

use sicList, replace  
gen ioind=""
replace ioind="020201" in 1/1  /* These are some IOIND-SIC mappings where we were unsure whether to include or not 
                                 (because there is a many-to-many matching problem: there are many IOINDS that 
                                 particular agricultural industries could be matched to.  In the final specification 
                                   we end up excluding these correspondences.   */
replace ioind="020202" in 2/2
replace ioind="020501" in 3/3
replace ioind="020600" in 4/4
replace ioind="020203" in 5/5
replace ioind="020401" in 6/6
replace ioind="020503" in 7/7
replace ioind="020702" in 8/8
replace sic4=139 in 1/4
replace sic4=179 in 5/7
replace sic4=291 in 8/8
keep if _n<=8
keep sic4 ioind
save addendum, replace

use sicList, replace
gen sic3=floor(sic4/10)
gen sic2=floor(sic4/100)
gen ioind=""
do doioindsic
keep ioind sic4
append using addendum
drop if ioind==""
save sicIOmatch, replace

use sicIOmatch, replace
replace ioind="110000" if substr(ioind,1,2)=="11"  /* We tried different specifications for construction.  In the end, we consider "Construction" one single industry
                                             (because this is how they are treated in the BEA IO Table.  The alternative is to consider the SIC2=16 (Heavy/highway construction
                                               as a separate IOIND (110400).  */
save sicIOmatchAlt, replace
count
local y=r(N)  /* Here is where we get rid of the "addendum correspondences" */
local yy=`y'-7
drop in `yy'/`y'
outsheet using sicIOmatchAlt.csv, replace delim(,)

insheet using ../../data/outside/downstream1987.csv, clear  
/* These were the datasets that were used for the Industry Classifications in the older (pre-2011) version of the paper */
ren  user industry
save temp1, replace
insheet using ../../data/outside/upstream1987.csv, clear
save temp2, replace
append using temp1
sort industry maker
keep if (industryuse>0.05 & industryuse<=1) |  (down>0.05 & down<=1)
save tempA, replace
keep if (industryuse>0.1 & industryuse<=1) |  (down>0.1 & down<=1)
save tempB, replace
keep if (industryuse>0.5 & industryuse<=1) |  (down>0.5 & down<=1)
save tempC, replace
use tempA, replace
tostring industry maker, replace force
replace industry="0"+industry if length(industry)<6
replace maker="0"+maker if length(maker)<6
drop if maker==industry
ren maker ioind
joinby ioind using sicIOmatchAlt
ren sic4 sicUp
ren ioind maker  
replace industry="110000" if substr(industry,1,2)=="11"  
/* The BEA IO tables have only record the amount produced/used for the coarse industry "Construction" (e.g., it does not 
                                                           record how much of different commodities were separately purchased by homebuilders, road pavers, etc...).  For this reason, 
                                                         it is necessary to aggregate, in the mapping between SIC codes and IOIND cods, all construction industries. */
ren industry ioind
joinby ioind using sicIOmatchAlt
ren ioind industry 
keep sic4 sicUp  downstreamuse industryuse
bys sic4 sicUp: keep if _n==1
save origTable5, replace
outsheet using origTable5.csv, replace delim(,)
use tempB, replace
tostring industry maker, replace force
replace industry="0"+industry if length(industry)<6
replace maker="0"+maker if length(maker)<6
drop if maker==industry
ren maker ioind
joinby ioind using sicIOmatchAlt
ren ioind maker
ren sic4 sicUp
ren industry ioind
joinby ioind using sicIOmatchAlt
ren ioind industry
keep sic4 sicUp downstreamuse industryuse
bys sic4 sicUp: keep if _n==1
save origTable10, replace
outsheet using origTable10.csv, replace delim(,)
use tempC, replace
tostring industry maker, replace force
replace industry="0"+industry if length(industry)<6
replace maker="0"+maker if length(maker)<6
drop if maker==industry
ren maker ioind
joinby ioind using sicIOmatchAlt
ren sic4 sicUp
ren ioind maker
ren industry ioind
joinby ioind using sicIOmatchAlt
ren ioind industry
keep sic4 sicUp  downstreamuse industryuse
bys sic4 sicUp: keep if _n==1
save origTable50, replace
outsheet using origTable50.csv, replace delim(,)

use sicTable01, replace    
/* Output definitions of vertically linked industries, using different cutoffs.  In this case, though, we do not allow industry I 
                              to be vertically linked with itself
                              Here, I is defined accordnig to the BEA's classification (we use this one to be more liberal about what a I-I link is, to make our 
                               robustness check more "robust")   */
joinby sic4 using sicIOmatch , unmatched(both)   
/* Here we merge in the correspondence between SICs and IOIND industries.  Because we want to define "I->I" according  
                                to the BEA definition */
drop if _merge==2
drop _merge
ren ioind ioindDown 
ren sic4 sicDown
ren sicUp sic4 
joinby sic4 using sicIOmatch , unmatched(both)
drop if _merge==2
drop _merge
ren ioind ioindUp
ren sic4 sicUp
ren sicDown sic4
drop if ioindDown==ioindUp  
drop ioindDown ioindUp
save sicTable01NoHorz, replace
outsheet using sicTable01NoHorz.csv, replace delim(,)
keep if frac>=.005   
save sicTable05NoHorz, replace
outsheet using sicTable05NoHorz.csv, replace delim(,)
keep if frac>=.01   
save sicTable10NoHorz, replace
outsheet using sicTable10NoHorz.csv, replace delim(,)
keep if frac>=.05   
save sicTable50NoHorz, replace
outsheet using sicTable50NoHorz.csv, replace delim(,)
keep if frac>=.10   
save sicTable100NoHorz, replace
outsheet using sicTable100NoHorz.csv, replace delim(,)
keep if frac>=.15   
save sicTable150NoHorz, replace
outsheet using sicTable150NoHorz.csv, replace delim(,)
keep if frac>=.20   
save sicTable200NoHorz, replace
outsheet using sicTable200NoHorz.csv, replace delim(,)

insheet using origTable5.csv, clear   /* These are the old (pre-2011 versions of the paper) definitions of vertically linked industries */
keep sicup sic4 
outsheet using origTable5.csv, replace delim(,)
insheet using origTable10.csv, clear
keep sicup sic4
outsheet using origTable10.csv, replace delim(,)
insheet using origTable50.csv, clear
keep sicup sic4
outsheet using origTable50.csv, replace delim(,)

